clear all
set more off
set memory 800m
set maxvar 10000

cd "D:\Dropbox\RA Work\RA Jim\Data"

*********************************************************************************************************
*********************************************************************************************************
**This file summarizes household demographics, and balance sheet information in aspects of real estates**
**, financial assets, vehicles and business. Data source: Survey of Consumer Finance 1983              **
*********************************************************************************************************
*********************************************************************************************************

use scf1983.dta,clear

* ****************************
* CONVERT TO MONTHLY PAYMENTS *
* ****************************
capture program drop MCONV
program MCONV, eclass
	args freq
	gen FR = (`freq'==5)+ (`freq'==6)/12
end ;

gen id=v1

*********
*Weights *
*********
*Recommended weight
gen weight=b3016

***************
*DEMOGRAPHICS*
**************
*AGE, Sex, Race of household head (HH)
gen age=b4503
gen sex=b3126 
label define sex 1 "Male" 2 "Female" 
gen race=b3111
label define race 1 "Caucasion" 2 "Black" 3 "Hispanic" 4 "Native American/Alaskan" 5 "Asian or Pacific Islander" 

*Education of HH
gen educ=b4505 
replace educ=-1 if educ==0 
replace educ=0 if educ==-6 

gen edcl=1 
replace edcl=4 if b4507==1
replace edcl=3 if b4507!=1 & educ>=13
replace edcl=2 if b4506==1 & educ<13 & b4507!=1
label define educ_class 1 "No HS" 2 "HS" 3 "Some College" 4 "College Degree"

*Marrital status
gen marrd=(b3112==1)

*Own home
gen ownhome=(b3702==1) 
label define ownhome 1 "Own home" 0 "Not own home"  


*Years at address 
*No variable in SCF given. Infered from questions: when do you move into your current home (if own home); into this country (if not own home) 
*For homeowner 
gen yradd=1986+1-max(0,b3712) if ownhome==1
*If this person inherited home and no date given, make it median year address among homeowners
replace yradd=15 if ownhome==1 & b3712==-6
*For non-homeowners, use years in this county as approxy
replace yradd=max(0,b3701) if ownhome==0
replace yradd=age if b3701==-7 & ownhome==0 


*Years at current job 
gen yrjob=max(0,b4543)

*Occupation categories
*Since b3114 categorization differs from later years. 
*It follows 1970, not 1980 3 digit occupation code. 
gen occup=b3114

*Denied credit or not in the past FEW years
*Note: since 1989, it's past 5 years 
gen denied_credit=(b5522==1 | b5522==3) 
label var denied_credit "Denied (partial or total) credit in last 5 years"


*Whether HH has any bank type credit cards
gen cbcc_hold=(b4108!=0) 
*Whether HH has any type credit cares
gen acc_hold=(b4103==1) 
*Credit card interest rate 
gen cc_r=max(0,b4124) 


*Deliquent
gen delinq=(b4207==5)  
replace delinq=-1 if b4207!=1 & b4207!=5
label define delinq -1 "N/A (payment not due/other/no loans/" 0 "Pay on time" 1 "Sometimes miss payment"


*Self employed or not
gen selfemp=(b4540==8) 

*Income 
gen income=max(0,b3201)
gen wageinc=max(0,b3205) 

*************************************
*NET WORTH; ASSET;DEBT;DEBT PAYMENT*
************************************

*+++++++++++++++ 1 ASSET ++++++++++++++++
*******1.1 REAL ESTATES *******
*value of home 
gen house=max(0,b3708)
*Value of other properties
gen otrs=max(0,b3801) 
*Land contracts and notes
gen llc=max(0,b3601) 

*******1.2 FINANCCIAL ASSETS*************** 
*Checking
gen cheque_acc=max(0,b3401) 
*Money market & call accounts
gen mmcall_acc=max(0,b3418) 
*Saving
gen saving=max(0,b3434) 
*IRA or KEOGH
gen retire_acc=max(0,b3446) 
*CD's
gen cds=max(0,b3453) 
*Govern't saving bond(Note: face value) 
gen save_bond=max(0,b3457) 
*other bonds 
gen other_bond_fv=max(0,b3458) 
*Stocks and Mutual funds
gen stock_mf=max(0,b3462) 
*Trusts excluding pension or company thrift accounts
gen trust=max(0,b3470) 
*cash value of life insurance
gen lf_ins=max(0,b3475) 
*Loans owed to household and gas leases
gen loan_claim=max(0,b3477) 
*Thrift accounts
gen thrift=max(0,b3306) 

*For consistency with other years
*b3302: Sum of checking accounts, money market accounts, saving accounts,
*IRAs and Keoghs, CDs and saving bonds, bonds, stock and mutual fund 
*holdings and trust accounts owned by household
*Included in subt_fin_asset since 1989 but not in b3302: lf_ins, loan_claim

gen subt_fin_asset=max(0,b3302)+lf_ins+loan_claim


************1.3 VEHICILES **************
gen vehicles=max(0,b3902) 

************1.4 BUSINESS ***************
*Net value of business: no active managment
gen biz_equ_hold_nam=max(0,b3501) 

*Net value of business: active management
*Note: b3502 is total value, not net value 
gen biz_equ_hold_am=max(0,b3503)+max(0,b3516) 

**Total non financial assets 
gen subt_nfin_asst=max(0,b3708)+max(0,b3801)+max(0,b3501)+max(0,b3502)+max(0,b3601)+max(0,b3902) 

***TOTAL ASSET 
gen assets=max(0,b3305) 

*-----------------------2. DEBTS--------------------------
******************2.1 REAL ESTATES*************
*Sum of 1st and 2nd mortgage loans on primary residence
gen debt_prin_rs=max(0,b4001) 
*Land contracts/notes
gen debt_lc=max(0,b3602) 
*Other properties
gen debt_other_rs=max(0,b3802) 

gen subt_debt_rs=max(0,b3318) 


*****************2.2 FINANCCIAL DEBTS***************
*Credit card 
gen debt_cc=max(0,b4102) 
gen debt_bcc=max(0,b4110) 
*Lines of credit 
gen debt_loc=max(0,b4125) 
*Only knows whether any of these LOCs are heloc, but no exact amount how big that is 

*Loans against the cash value of life insurance 
gen debt_lfins=max(0,b4204) 
*Other consumer loans 
gen debt_cl=max(0,b4206) 

*Total of revolving debt
gen debt_revolv=max(0,b4101) 



*****************2.3 VEHICLES***************
*Automobile purchases
gen debt_vehicle=max(0,b4205) 

*Total consumer debt 
*The sum of total closed-end consumer debt (total amount outstanding 
*for all debts owed by the household which are listed in the Consumer Loan
*Section, excluding loans against the cash value of life insurance policies) 
*and revolving charge debt 
gen cons_debt=max(0,b3319)

gen t_debt=max(0,b3320) 

*--------------------------3 DEBT PAYMENT ----------------------
*Regular & Non-regular 
*gen debtpayment=max(0,b4202)+max(0,b4203) 
*Credit cards
gen debtpay_cc=0.025*debt_cc

*Lines of credit

*Land contract
gen debtpay_lc=(1.08^(1/12)-1)*debt_lc

*Mortgages on properties
gen debtpay_mort=0 
MCONV b4011 
replace debtpay_mort=debtpay_mort+FR*max(0,b4010)
drop FR
MCONV b4033 
replace debtpay_mort=debtpay_mort+FR*max(0,b4032) 
drop FR

*Consumer loans 
*Including home repair D6 (3 loans), vehicle purchase E10(3 loans),
*Durable good purchases F6 (3 loans), 3rd mortage C11 (1 loan )
*Cannot figure out the rest 4 as there's no explicit variable mapping on the questionaire
gen debtpay_cl=0 
local cl_mconv "b4220 b4240 b4260 b4280 b4300 b4320 b4340 b4360 b4380 b4400 b4420 b4440 b4460 b4480"
local cl_pay "b4219 b4239 b4259 b4279 b4299 b4319 b4339 b4359 b4379 b4399 b4419 b4439 b4459 b4479"
local i=1 
local n: word count `cl_mconv'
while `i'<=`n' {
	local var2conv: word `i' of `cl_mconv'
	local var_pay: word `i' of `cl_pay'
	MCONV `var2conv' 
	replace debtpay_cl=debtpay_cl+`var2conv'*`var_pay' 
	drop FR 
	local i=`i'+1 
} 

gen subt_debtpay=debtpay_cc+debtpay_lc+debtpay_mort+debtpay_cl

*************
* NET WORTH *
*************
gen networth=max(0,b3324) 


*************
*LIQUID ASSET*
*************
gen liquid=max(0,b3301) 

drop v1 b*

rename cbcc_hold bcc_hold

save basics_1983.dta,replace 


