clear all
set more off
set memory 800m
set maxvar 10000

*********************************************************************************************************
*********************************************************************************************************
**This file summarizes household demographics, and balance sheet information in aspects of real estates**
**, financial assets, vehicles and business. Data source: Survey of Consumer Finance 1989-2010         **
**Last update: July 14, 2015                                                                           **
*********************************************************************************************************
*********************************************************************************************************



cd "D:\Dropbox\RA Work\RA Jim\Data"

local year=2010

use scf`year'.dta,clear


if (`year'==1989) {
    renpfix X x
	renpfix J j
	gen id=x1
	}
if (`year'>1989) {
    renpfix X x
	renpfix Y y
	renpfix J j
	gen id=y1
	}

********
*Weights*
********
gen weight=x42001


* ****************************
* CONVERT TO MONTHLY PAYMENTS *
* ****************************
* Program MCONV converts payments to MONTHLY basis 
* It takes the SCF frequency code and returns a scalar variable that can be used to rescale payments
* Note: this macro does not convert HOURLY (SCF coding 18) or DAILY (SCF coding 1) or one time payment (SCF coding 8) 
* for DSR calculation (monthly, for consistency w/ James. Shouldn't matter for probit estimates) ???
* We make other (SCF coding -7) and varies (SCF coding 22) to be median frequency: monthly
capture program drop MCONV
program MCONV, eclass
	args freq
	gen FR = (`freq'==2)*52/12+(`freq'==3 | `freq'==31)*26/12+(`freq'==4 | `freq'==-7 | `freq'==22)+(`freq'==23)*13/12+(`freq'==24)/6*52/12+(`freq'==5 )/3+(`freq'==6)/12+(`freq'==11)/6+(`freq'==12)/2+(`freq'==31)*2
end ;

**************
*DEMOGRAPHICS*
**************

*AGE of household head (HH)
gen age=x14

*Education of HH
gen educ=x5901
*Education coding: -1 stands for no education. We replace it by 0
replace educ=0 if educ==-1

*Education of HH head: No HS degree & College Degree
gen edcl=1
replace edcl=4 if (x5904 == 1)
replace edcl=3 if (x5904!=1 & educ >=13)
replace edcl=2 if (inlist(x5902,1,2) & educ <13 & x5904!=1)
label define educ_class 1 "No HS" 2 "HS" 3 "Some College" 4 "College Degree"


*Marital status: marriage coding: 1 married; 2 living w/. a partner.
gen marrd=(x8023==1 | x8023==2 ) 

*Race of HH 
gen race=.
gen racecl=.

if (`year' >= 1998) {
	replace race=1 if (x6809==1)
	replace race=2 if (x6809==2)
	replace race=3 if (x6809==3)
	replace race=5 if (!inlist(x6809,1,2,3))
	replace racecl=1+(x6809 != 1 | x6810 !=5)
	}

if (`year' < 1998) {
	replace race=1 if (x5909==5)
	replace race=2 if (x5909==4)
	replace race=3 if (x5909==3)
	replace race=5 if (!inlist(x5909,3,4,5))
	replace racecl=1+(x5909 != 5)
	}

label define race_cat 1 "White" 2 "Black" 3 "Hispanic" 5 "Other"
label values race race_cat

*Own home:
*x508: Own all/part farm/ranching. SCF coding: 1. ows all; 2. owns part 
*x601: Own either a mobile home or a site. SCF coding: 1 home & site; 2 site but not home; 3 home but not site 
*x701: Mutiple HU structure. SCF coding: 1 owns or is buying/land contract; 3 condo; 4 co-op; 5 townhouse ass.;6 retirement lifetime tenancy 
if (`year'<1995) {
	gen ownhome=(inlist(x508,1,2) | inlist(x601,1,2,3) | inlist(x701,1,3,4,5,6))
}
if (`year'>=1995) {
	gen ownhome=(inlist(x508,1,2) | inlist(x601,1,2,3) | inlist(x701,1,3,4,5,6,8) | (x701==-7 & x7133==1))
}
label define ownhome 1 "Own Home" 0 "Not Own Home"

*Years at address:
**Farm owned by business
gen yradd=`year'+1-x516 if x516!=0
**Mobile home: site purchased
replace yradd=`year'+1-x606 if x606!=0
**Mobile home: neither own nor rent
replace yradd=`year'+1-x611 if x611!=0
**Mobile home: home purchased
replace yradd=`year'+1-x616 if x616!=0
**Mobile home: rent
replace yradd=`year'+1-x622 if x622!=0
**Mobile home: both home and site owned
replace yradd=`year'+1-x626 if x626!=0
**Neither rent or own
replace yradd=`year'+1-x707 if x707!=0
**Other rent
replace yradd=`year'+1-x713 if x713!=0
**Multiple HU structure
replace yradd=`year'+1-x720 if x720!=0
***Missing year info for condo/co-op/townhouse ass.
replace yradd=. if x701==3 | x701==4 | x701==5
***Reporting error. E.g. some people in 1989 claim that they move in the current address in 1990!
replace yradd=. if yradd<0

 *Years at current job
 gen yrjob=x4115
 
 
 *Occupation categories
 gen occup=x7401
 replace occup=8 if x7401==0
 *Coding of x4100: 50 retired and not working; 13 retired but still working
 replace occup=7 if (x4100==50 | x4100==13)
 label define jobs 1 "Executive/Manager" 2 "Sales/Admin Support" 3 "Service" 4 "Production/Repair" 5 "Laborers" 6 "Farmers" 7 "Retired" 8 "Not Working" 
 label values occup jobs

 
 *Denied credit or not
 *407 coding: 1 turned down; 3 not as much credit (as one applies for)
 gen denied_credit=(x407==1 | x407==3)
 label var denied_credit "Denied (partial or total) credit in last 5 years"
 
 *Whether HH has any bank type credit cards
 gen bcc_hold=(x411>0)
 *Whether HH has any credit card
 gen acc_hold=(x410==1) 
 
 *Credit card interest rate
 if (`year' >= 1995) {
	gen ccir=x7132
	replace ccir=. if ccir==0 
	replace ccir=0 if ccir==-1
	}

 *Delinquent
 gen delinq=(x3004==5)
 replace delinq=-1 if x3004!=5 & x3004!=1
 label define delinquency -1 "N/A (payment not due/other/no loans/" 0 "Pay on time" 1 "Sometimes miss payment"

 *Among delinquent HHs, who were behind in payments >= 2 months
 gen delinq60=-1
 replace delinq60=1 if (x3005==1)
 replace delinq60=0 if (x3005==5)
 
 *Self-employed or not 
 gen selfemp=(x4106==2)
 
 *Income
 gen income=max(0,x5729)
 
 *Health insurance
 if (`year'<=2007) {
	 *Everyone in family has health insurance: govern't funded, x6306
	 gen hinsgov=(x6306==1)
     *Everyone in family has health insurance: private, x6329
	 gen hinsprvt=(x6329==1)
	 *Everyone in family has health insurance: either govern't or private
	 gen hins=(hinsgov==1 | hinsprvt==1)
	 }
  if (`year'==2010) {
     *Everyone in family has some type of health insurance
	 gen hins=(x6357==1) 
	 }
	 
	 
 
 *****************************************
 *NET WORTH ; ASSET ; DEBT ; DEBT PAYMENT*
 *****************************************
 
 *************1 REAL ESTATES ASSETS/DEBTS/DEBT PAYMENTS***************
 *+++++++++++++1.1 ASSET ++++++++++++++++
 *(1) Principal Residence:
 *= x513, value of a farm/ranching if respondant lives in and own ENTIRE farm/ranching 
 *= x526 value of the part of a farm/ranching if respondant lives in and own part of it
 *= x604(site), x614(mobile home), x623(both) value of mobile home/site if he lives in a mobile home 
 *= x716 all others
 *Value of farm/ranch residence is the non-business part. x507 the fraction used for farm/ranching.
 gen house_fr=(max(0,x513)+max(0,x526))*(1-x507/1d4)
 gen house=house_fr+x604+x614+x623+x716
 
 
 *(2) Loan/Land contract:
 *x1*05: how much are owed on this note; x1*09: how much is still owed on this note
 if (`year'<=2007) {
	 gen llc= max(x1405,x1409)+max(x1505, x1509)+max(x1605,x1609)+max(0,x1619)
}
 if (`year'==2010) {
	 gen llc= max(x1405,x1409)+max(x1505, x1509)+max(0,x1619)
}

 
 *(3) Other real estates
 *<1> Residential part: total 5 other real estates
 if (`year'<=2007) {
	gen otrs_rs=(inlist(x1703,12,14,21,22,25,40,41,42,43,44,49,50,52,999))*x1705/1d4*max(0,x1706)+(inlist(x1803,12,14,21,22,25,40,41,42,43,44,49,50,52,999))*x1805/1d4*max(0,x1806)+(inlist(x1903,12,14,21,22,25,40,41,42,43,44,49,50,52,999))*x1905/1d4*max(0,x1906)+max(0,x2002)
}
 if (`year'==2010) {
	gen otrs_rs=(inlist(x1703,12,14,21,22,25,40,41,42,43,44,49,50,52,999))*x1705/1d4*max(0,x1706)+(inlist(x1803,12,14,21,22,25,40,41,42,43,44,49,50,52,999))*x1805/1d4*max(0,x1806)+max(0,x2002)
}
 *Other Non-Residential Real Estates(Net Asset) 
 gen otrs_nrs=(inlist(x1703,1,2,3,4,5,6,7,10,11,13,15,24,45,46,47,48,51,-7))*(max(0,x1706)-max(0,x1715))*(x1705/1d4)
 replace otrs_nrs=otrs_nrs+(inlist(x1803,1,2,3,4,5,6,7,10,11,13,15,24,45,46,47,48,51,-7))*(max(0,x1806)-max(0,x1815))*(x1805/1d4)
 if (`year'<=2007) {
	replace otrs_nrs=otrs_nrs+(inlist(x1903,1,2,3,4,5,6,7,10,11,13,15,24,45,46,47,48,51,-7))*(max(0,x1906)-max(0,x1915))*(x1905/1d4)
 }
 replace otrs_nrs=otrs_nrs+(max(0,x2012)-max(0,x2016))
 
 *Indicator when net non-residential real estate (before subtracting debt from consumer loans when they are used for real estate investment) >0 
 *We need to subtract the consumer loans from non-res real estate book value when the purpose is for real estate investment 
 gen flag781=(otrs_nrs>0) 
 replace otrs_nrs=otrs_nrs-x2723*(x2710==78)-x2740*(x2727==78)-x2823*(x2810==78)-x2840*(x2827==78)-x2923*(x2910==78)-x2940*(x2927==78) if flag781==1
   
  *1.1 SUBTOTAL
  gen subt_rs_asset=house+llc+otrs_rs+otrs_nrs
  
 *-------------1.2 DEBT ----------------
  *(1) Principal Residence Mortgage: 
  * x805,x905 mortgage on this property, Let's name it HM1, HM2;
  * x1005 mortage backed up by this property. Let's name it HEM
 gen non_farm_share=(1-max(0,x507)/1d4)*(x507>0)+(x507<=0)
  *If one lives on farm/ranch, mortgage we examine is only the part for residential purpose;
  *If one does not live on farm/rach, x507 is not applicable with coding 0. Thus non_farm_share=1.
 gen debt_prin_rs=non_farm_share*(max(0,x805)+max(0,x905)+max(0,x1005))
 
  *(2) Loan/Land contract:
  if (`year'<=2007) {
	gen debt_lc=max(0,x1417)+max(0,x1517)+max(0,x1617)+max(0,x1621)
 }
  if (`year'==2010) {
	gen debt_lc=max(0,x1417)+max(0,x1517)+max(0,x1621)
 }
		
 
  *(3) Other real estates: Residential Part (x2016 is regarded as non-residential)
  *Assuming the debt share is as the value share reported earlier. 
 gen debt_other_rs=(inlist(x1703,12,14,21,22,25,40,41,42,43,44,49,50,52,999))*x1705/1d4*max(0,x1715)
 replace debt_other_rs=debt_other_rs+(inlist(x1803,12,14,21,22,25,40,41,42,43,44,49,50,52,999))*x1805/1d4*max(0,x1815)
 if (`year'<=2007) {
	replace debt_other_rs=debt_other_rs+(inlist(x1903,12,14,21,22,25,40,41,42,43,44,49,50,52,999))*x1905/1d4*max(0,x1915)+max(0,x2006)
}
 if (`year'==2010) {
	replace debt_other_rs=debt_other_rs+max(0,x2006)
} 
 *Including the debt under SCF section Consumer Loans of which purpose is for either residential real estates (coding 67)
 *or non-residential estate (coding 78) which happens when otrs_nrs=0 & otrs_rs>0
 gen flag67=(otrs_rs>0) 
 replace debt_other_rs=debt_other_rs+x2723*(x2710==67)+x2740*(x2727==67)+x2823*(x2810==67)+x2840*(x2827==67)+x2923*(x2910==67)+x2940*(x2927==67) if flag67==1
 replace debt_other_rs=debt_other_rs+x2723*(x2710==78)+x2740*(x2727==78)+x2823*(x2810==78)+x2840*(x2827==78)+x2923*(x2910==78)+x2940*(x2927==78) if flag781==0 & flag67==1

 *(4) Debt for other home purchases and home improvements 
 gen debt_hp_hi=max(0,x1044)+max(0,x1215)+max(0,x1219)
 
 
  *[2] LINES OF CREDIT
 *[2.1] Home equity backed LOC, for non-farm owners and farm-owners, non-farm part: first 3
 gen debt_heloc=non_farm_share*((x1103==1)*x1108+(x1114==1)*x1119+(x1125==1)*x1130)
 *Other lines of credit (more than 3) 
 *Whether other LOCs x1136 are backed by home equity not given in SCF. We assume % of HELOC as in the first 3 LOCs.  
 *<1> When debt_heloc is 0, assume that the heloc equals to 50% of x1136 when individual has housing value>0
 gen debt_heloc_other=0
 replace debt_heloc_other=max(0,x1136)*debt_heloc/(non_farm_share*(x1108+x1119+x1130)) if (x1108!=0 | x1119!=0 | x1130!=0)
 replace debt_heloc_other=0.5*max(0,x1136)*(house>0)  if x1108==0 & x1119==0 & x1130==0
 
 *[2.2] Non home equity backed loc
 gen debt_nheloc=non_farm_share*((x1103!=1)*x1108+(x1114!=1)*x1119+(x1125!=1)*x1130) 
 gen debt_nheloc_other=max(0,x1136)-debt_heloc_other 
 
 gen nheloc=debt_nheloc+debt_nheloc_other
 
 *<<<<<<<<<Other info of lines of credit>>>>>>>>>>>>*
 *Having access to (secured and uncsecured) LOC: self-reported 
 gen hloc=(x1101==1)
 *Having access to unsecured LOC
 *Homeowner: access to LOC & one of reported LOCs are unsecured; Non-homeowner: access to LOC and presumably it's unsecured. 
 gen hnheloc1=(x1101==1)*(x1103==5 | x1114==5 | x1125==5)*(ownhome==1)+(x1101==1)*(ownhome==0) 
 *Alternative mesure of acces to unsecured LOC: de facto. 
 gen hnheloc2=(debt_nheloc_other>0)
 gen hnheloc=(hnheloc1==1 | hnheloc2==1) 

 *1.2 SUBTOTAL
 gen subt_rs_debt=debt_prin_rs+debt_lc+debt_other_rs+debt_hp_hi+(debt_heloc+debt_heloc_other+debt_nheloc+debt_nheloc_other) 
 
 *-------------1.3 DEBT PAYMENT ----------
  *(1) Principal Residence Mortgage:
  gen debtpay_prin_rs=0
 local prs_mconv "x809 x909 x1009 x814 x914 x1014"
 local prs_pay "x808 x908 x1008 x813 x913 x1013"
 local i=1
 local n: word count `prs_mconv'
 while `i'<=`n' {
 	local var2conv: word `i' of `prs_mconv'
 	local var_pay: word `i' of `prs_pay'
 	MCONV `var2conv'
  replace debtpay_prin_rs=debtpay_prin_rs+FR*max(0,`var_pay')*non_farm_share
  drop FR
  local i=`i'+1
}

 *(2) Land contract
 *Assuming a 8% annual interest rate
 gen debtpay_lc=(1.08^(1/12)-1)*debt_lc
 
 *(3) Other real estates (Only residential part) 
 gen debtpay_other_rs=0
 *First 2 are regular payment; last 2 are typical payment.
 *Loan payment x1918 and x1923 are only for before 2007. 
 local ors_mconv "x1719 x1819 x1724 x1824"
 local ors_pay "x1718 x1818 x1723 x1823"
 local ors_share "x1705 x1805 x1705 x1805"
 local ors_type "x1703 x1803 x1703 x1803"
 local i=1
 local n: word count `ors_mconv'
 while `i'<=`n' {
 	 local var2conv: word `i' of `ors_mconv'
 	 local var_pay: word `i' of `ors_pay'
 	 local var_share: word `i' of `ors_share'
	 local var_type: word `i' of `ors_type'
 	 MCONV `var2conv'
 	 replace debtpay_other_rs=debtpay_other_rs+(inlist(`var_type',12,14,21,22,25,40,41,42,43,44,49,50,52,999))*FR*max(0,`var_pay')*`var_share'/1d4
 	 drop FR
 	 local i=`i'+1
 }
 
 *Loan payment x1918 and x1923 are only for years before 2007. 
 if (`year'<=2007) {
    MCONV x1919 
	replace debtpay_other_rs=debtpay_other_rs+(inlist(x1903,12,14,21,22,25,40,41,42,43,44,49,50,52,999))*FR*max(0,x1918)*x1905/1d4
	drop FR 
	MCONV x1924
	replace debtpay_other_rs=debtpay_other_rs+(inlist(x1903,12,14,21,22,25,40,41,42,43,44,49,50,52,999))*FR*max(0,x1923)*x1905/1d4
	drop FR
 }
 
 *For remaining properties in other real estates
 MCONV x2008
 replace debtpay_other_rs=debtpay_other_rs+FR*max(0,x2007) 
 drop FR
 
 MCONV x2018
 replace debtpay_other_rs=debtpay_other_rs+FR*max(0,x2017)
 drop FR
 
 *(4) Other home purchases and home improvements from SECTION of CONSUMER LOANS in codebook
 *Regular payment: Loan 7, 8, 9 of consumer loans in 1989 codebook 
 MCONV x1221
 gen MFRQx1221=FR
 drop FR
 if (`year'<=1989) {
	 gen debtpay_hp_hi_reg=max(0,x1039)+max(0,x1210)+max(0,x1220)*MFRQx1221
}
 if (`year'>=1992) {
	 MCONV x7567 
	 gen MFRQx7567=FR
	 drop FR
	 MCONV x7565
	 gen MFRQx7565=FR
	 drop FR
	 gen debtpay_hp_hi_reg=MFRQx7567*max(0,x1039)+MFRQx7565*max(0,x1210)+max(0,x1220)*MFRQx1221
 }
 
 *Typical payment if there's no regular payment: Loan 7, 8
 MCONV x1041
 gen MFRQx1041=FR
 drop FR
 MCONV x1212
 gen MFRQx1212=FR
 drop FR
 gen debtpay_hp_hi_typ=max(0,x1040)*MFRQx1041+max(0,x1211)*MFRQx1212
 
 gen debtpay_hp_hi=debtpay_hp_hi_reg+debtpay_hp_hi_typ

 *1.3 SUBTOTAL
 gen subt_rs_debtpay=debtpay_prin_rs+debtpay_lc+debtpay_other_rs+debtpay_hp_hi
 
 *---------------1.4 Other Payment--------------------
 *Rent and condo fees
 gen rent=0
 local rent_mconv "x522 x603 x613 x620 x704 x709" 
 local rent_pay "x521 x602 x612 x619 x703 x708"
 local i=1
 local n: word count `rent_mconv'
 while `i'<=`n' {
	local var2conv: word `i' of `rent_mconv'
	local var_pay: word `i' of `rent_pay'
	MCONV `var2conv'
    replace rent=rent+FR*max(0,`var_pay')
    drop FR 
	local i=`i'+1
	}
 
 *Real estates tax
 MCONV x722
 gen rstax=FR*max(0,x721)
 drop FR
 
 gen subt_rs_otpay=rent+rstax 
 
 *Subtotal with debtpay
 gen subt_rs_allpay=subt_rs_debtpay+subt_rs_otpay
 
 ********2 FINANCIAL ASSETS/DEBTS/DEBT PAYMENTS*******
 *++++++++++2.1 Asset+++++++++++++++++
 *(1) Checking accounts
 *Coding: x3506: -1, nothing, and zero; 0, inapplicable (no further checking accounts)
 gen cheque_acc=max(x3506,0)+max(x3510,0)+max(x3514,0)+max(x3518,0)+max(x3522,0)+max(x3526,0)+max(0,x3529)
 *(2) IRA or Keogh accounts
 if (`year'<2004) {
	gen retire_acc=max(x3610,0)+max(x3620,0)+max(x3630,0)  
 }
 if (`year'>=2004) {
	gen retire_acc=0+max(0,x6551)+max(0,x6559)+max(0,x6567)+max(0,x6552)+max(0,x6560)+max(0,x6568)+max(0,x6553)+max(0,x6561)+max(0,x6569)+max(0,x6554)+max(0,x6562)+max(0,x6570)
 }
 
 *(3) Money-market accounts
 if (`year'<2004) {
	gen mm_acc=max(x3706,0)+max(x3711,0)+max(x3716,0)+max(0,x3718)
 }
 if (`year'>=2004) {
	gen mm_acc=max(0,x3730)*inlist(x3732,4,30)+max(0,x3736)*inlist(x3738,4,30)+max(0,x3742)*inlist(x3744,4,30)+max(0,x3748)*inlist(x3750,4,30)+max(0,x3754)*inlist(x3756,4,30)+max(0,x3760)*inlist(x3762,4,30) 
 }

 *(4) Call account in Brokerages
 gen bro_acc=max(0,x3930)
 *(5) CD's 
 gen cds=max(0,x3721)
 *(6) Saving accounts
 *Since 2004, saving and money market account info are in the same section
 if (`year'<2004) {
	gen saving_acc=max(0,x3804)+max(0,x3807)+max(0,x3810)+max(0,x3813)+max(0,x3816)+max(0,x3818)
 }
 if (`year'>=2004) {
	gen saving_acc=max(0,x3730)*(!inlist(x3732,4,30))+max(0,x3736)*(!inlist(x3738,4,30))+max(0,x3742)*(!inlist(x3744,4,30))+max(0,x3748)*(!inlist(x3750,4,30))+max(0,x3754)*(!inlist(x3756,4,30))+max(0,x3760)*(!inlist(x3762,4,30))
} 

 *(7) Mutual fund
gen mf=max(0,x3822)+max(0,x3824)+max(0,x3826)+max(0,x3828)+max(0,x3830)
*Additional other mutal funds since 2004
 if (`year'>=2004) {
	replace mf=mf+max(0,x7787)
 }

 *(8) Govn't saving Bonds(Note: face value)
 gen save_bond=max(0,x3902)
 *(9) Other bonds (Note: face value)
 *Mortgage backed bonds
 gen other_bond_fv=max(0,x3906)
 *US government bonds or treasury bills
 replace other_bond_fv=other_bond_fv+max(0,x3908)
 *State or municipal bonds or other taxfree bonds
 replace other_bond_fv=other_bond_fv+max(0,x3910)
 *Corporate bonds and foriegn bonds 
 if (`year'<1992) {
	replace other_bond_fv=other_bond_fv+max(0,x3912) 
 }
 if (`year'>=1992) {
	replace other_bond_fv=other_bond_fv+max(0,x7634)+max(0,x7633)
} 

*(9)' Other bonds (Note: Market value) 
*NOTE: Before 1992 (since 1992), there are no (there are) market value for all other bonds
*So create a new variable (other_bond_mv) to represent the market value of these other bonds
 if (`year'>=1992) {
	*Mortgage backed bonds
	 gen other_bond_mv=max(0,x7635)
	 *US government bonds or treasury bills
	 replace other_bond_mv=other_bond_mv+max(0,x7636)
	 *State or municipal bonds or other taxfree bonds
	 replace other_bond_mv=other_bond_mv+max(0,x7637)
	 *Corporate bonds and foriegn bonds 
	 replace other_bond_mv=other_bond_mv+max(0,x7639)+max(0,x7638)
} 

 *(10) Stocks
 gen stock=x3915
 *(11)Values of interests in annuities, trusts or managed investment
 if (`year'<=1995) {
	gen atm_int=max(0,x3942) 
 }
 if (`year'==1998 | `year'==2001) {
	gen atm_int=max(0,x6820)+max(0,x6835)
 }
 if (`year'>=2004) {
	gen atm_int=max(0,x6577)+max(0,x6587)
 }
 
 *(12) Pension plan 
 *[1] Formula type pension not included in his code: no pension_A_r & pension_A_s
 *[2] In Account-type pension, only THRIFT and Saving & 401k/403b/SRA & cashable pension are considered:
 *restrictions apply to variables x4*26 and x4*36. 
 
 if (`year'<2004) {
 *Not including include formula type or not 
 * Type A (Formula type)& respondent
 /*
 gen pension_A_r=max(0,x4204)+max(0,x4304)+max(0,x4404)  
 *Type A & spouse
 gen pension_A_s=max(0,x4804)+max(0,x4904)+max(0,x5004)
 */
 *Revised on Dec. 13, 2014
 
 *Only include 401k, 403b, thrift and savings type or if the owner can borrow or withdraw
 *Type B (Account type) & respondent
	 gen pension_B_r=max(0,x4226)*(inlist(x4216,1,2,7,11,12,18) | x4227==1 | x4231==1)
	 replace pension_B_r=pension_B_r+max(0,x4326)*(inlist(x4316,1,2,7,11,12,18) | x4327==1 | x4331==1)
	 replace pension_B_r=pension_B_r+max(0,x4426)*(inlist(x4416,1,2,7,11,12,18) | x4427==1 | x4431==1) 
	 *Type B & spouse 
	 gen pension_B_s=max(0,x4826)*(inlist(x4816,1,2,7,11,12,18) | x4827==1 | x4831==1)
	 replace pension_B_s=pension_B_s+max(0,x4926)*(inlist(x4916,1,2,7,11,12,18) | x4927==1 | x4931==1) 
	 replace pension_B_s=pension_B_s+max(0,x5026)*(inlist(x5016,1,2,7,11,12,18) | x5027==1 | x5031==1) 
	 *Use informations of the three pensions for characterstics of this other pension
	 *Other pensions respondent & spouse
	 gen pension_other=max(0,x4436)*(inlist(x4216,1,2,7,11,12,18) | inlist(x4316,1,2,7,11,12,18) | inlist(x4416,1,2,7,11,12,18) | x4227==1 | x4327==1 | x4427==1 | x4231==1 | x4331==1 | x4431==1)
	 replace pension_other=pension_other+max(0,x5036)*(inlist(x4816,1,2,7,11,12,18) | inlist(x4916,1,2,7,11,12,18) | inlist(x5016,1,2,7,11,12,18) | x4827==1 | x4927==1 | x5027==1 | x4831==1 | x4931==1 | x5031==1)
 }
 
 if (`year'>=2004 & `year'<=2010){
    gen temp_B_r0=(inlist(x11000,5,6,10,21) | inlist(x11001,2,3,4,6,20,21,22,26) | x11025==1 | x11031==1)
	gen pension_B_r=max(0,x11032)*temp_B_r0
	
	gen temp_B_r1=(inlist(x11100,5,6,10,21) | inlist(x11101,2,3,4,6,20,21,22,26) | x11125==1 | x11131==1)
	replace pension_B_r=pension_B_r+max(0,x11132)*temp_B_r1
	
	if (`year'!=2010) {
	gen temp_B_r2=(inlist(x11200,5,6,10,21) | inlist(x11201,2,3,4,6,20,21,22,26) | x11225==1 | x11231==1)
	replace pension_B_r=pension_B_r+max(0,x11032)*temp_B_r2
	}
	
	gen temp_B_s3=(inlist(x11300,5,6,10,21) | inlist(x11301,2,3,4,6,20,21,22,26) | x11325==1 | x11331==1)
    gen pension_B_s=max(0,x11332)*temp_B_s3
	
	gen temp_B_s4=(inlist(x11400,5,6,10,21) | inlist(x11401,2,3,4,6,20,21,22,26) | x11425==1 | x11431==1)
	replace pension_B_s=pension_B_s+max(0,x11432)*temp_B_s4
	
	if (`year'!=2010) {
	gen temp_B_s5=(inlist(x11500,5,6,10,21) | inlist(x11501,2,3,4,6,20,21,22,26) | x11525==1 | x11531==1)
	replace pension_B_s=pension_B_s+max(0,x11532)*temp_B_s5
    }
	
	if (`year'!=2010) {
    gen pension_other=max(0,x11259)*(temp_B_r0==1 | temp_B_r1==1 | temp_B_r2==1)
    replace pension_other=pension_other+max(0,x11559)*(temp_B_s3==1 | temp_B_s4==1 | temp_B_s5==1) 
	drop temp_B_r0 temp_B_r1 temp_B_r2 temp_B_s3 temp_B_s4 temp_B_s5
    }
	if (`year'==2010) {
    gen pension_other=max(0,x11259)*(temp_B_r0==1 | temp_B_r1==1 )
	replace pension_other=pension_other+max(0,x11559)*(temp_B_s3==1 | temp_B_s4==1 )
    drop temp_B_r0 temp_B_r1 temp_B_s3 temp_B_s4
   }	
	
 }
 
 *Future Pension
 if (`year'<2010) {
	gen fut_pension=max(0,x5604)+max(0,x5612)+max(0,x5620)+max(0,x5628)+max(0,x5636)+max(0,x5644)
 }
 if (`year'==2010) {
	gen fut_pension=max(0,5604)+max(0,x5612)+max(0,x5620)+max(0,x5628) 
 }
 
 *Since 2001, value of pensions that R or S are currently receiving benefits from are reported
 *We checked and found that most of them are not 401k or other types recorded under account type pension 
 if (`year'==2001) {
	gen cur_pension=max(0,x6462)+max(0,x6467)+max(0,x6472)+max(0,x6477)+max(0,x6482)+max(0,x6487)
}
if (`year'==2004 | `year'==2007) {
	gen cur_pension=max(0,x6462)+max(0,x6467)+max(0,x6472)+max(0,x6477)+max(0,x6482)+max(0,x6487)+max(0,x6957)
	}
if (`year'==2010) {
	gen cur_pension=max(0,x6462)+max(0,x6467)+max(0,x6472)+max(0,x6477)+max(0,x6957)
}

 
 *Total pension
 gen pp=pension_B_r+pension_B_s+pension_other+fut_pension

 if (`year'>=2001) {
    replace pp=pp+cur_pension
 }
 
 *(13)Cash value of Life insurance: 
 gen lf_ins=x4006
 
 *(14) Other assets: financial part
 gen other_fin=x4018+x4022*(inlist(x4020,61,62,63,64,65,66,71,72,73,74,77,80,81,-7))+x4026*(inlist(x4024,61,62,63,64,65,66,71,72,73,74,77,80,81,-7))+x4030*(inlist(x4028,61,62,63,64,65,66,71,72,73,74,77,80,81,-7))
 
 *2.1 SUBTOTAL
 gen subt_fin_asset=(cheque_acc+mm_acc+cds+saving_acc+mf+bro_acc)+stock+other_bond_fv+(retire_acc+pp)+save_bond+lf_ins+atm_int+other_fin
 
 *-----------2.2 DEBT-----------------------
 *[1] CREDIT CARDS
 if (`year'<1992) {
	gen debt_cc=max(0,x413)+max(0,x421)+max(0,x424)+max(0,x427)+max(0,x430)
  }
 if (`year'>=1992 & `year'<2010) {
	gen debt_cc=max(0,x413)+max(0,x421)+max(0,x424)+max(0,x427)+max(0,x430)+max(0,x7575)
 }
 if (`year'==2010) {
	gen debt_cc=max(0,x413)+max(0,x421)+max(0,x427)+max(0,x430)+max(0,x7575)
 }
 gen debt_bcc=max(0,x413)
 
*[3] CONSUMER LOANS
*No breakup here according to loan usage as in James code
*Loans for home purchases and home improvements, and loans for vehicles are put under residence and vehicles
gen debt_cl=x2723*(!inlist(x2710,67,78))+x2740*(!inlist(x2727,67,78))+x2823*(!inlist(x2810,67,78))+x2840*(!inlist(x2827,67,78))+x2923*(!inlist(x2910,67,78))+x2940*(!inlist(x2927,67,78))
*If no other residential real estate, but still have consumer loans for purpose 67
replace debt_cl=debt_cl+x2723*(x2710==67)+x2740*(x2727==67)+x2823*(x2810==67)+x2840*(x2827==67)+x2923*(x2910==67)+x2940*(x2927==67) if flag67==0
replace debt_cl=debt_cl+x2723*(x2710==78)+x2740*(x2727==78)+x2823*(x2810==78)+x2840*(x2827==78)+x2923*(x2910==78)+x2940*(x2927==78) if flag67==0 & flag781==0 
 
*Since 1995, there are 7th: other remaining loans in consumer loans section. 
if (`year'>=1995) {
	replace debt_cl=debt_cl+max(0,x7183)
}
  
*[3]' Since 1992, education loans are listed seperately, but we are going to include it into variable "debt_cl"
if (`year'>=1992) {
	 gen debt_edul=max(0,x7824)+max(0,x7847)+max(0,x7870)+max(0,x7924)+max(0,x7947)+max(0,x7970)
	 replace debt_cl=debt_cl+debt_edul
	 if (`year'>=1995) {
		replace debt_edul=debt_edul+ max(0,x7179) 
		replace debt_cl=debt_cl+ max(0,x7179) 
	  }
}
  

*Installment loans classified under unsecured credit *
gen sec_purpose1=inlist(x2710,1,3,4,10,24,61,63,65,67,69,71,72,73,74,75,76,78,79,83)
gen sec_purpose2=inlist(x2727,1,3,4,10,24,61,63,65,67,69,71,72,73,74,75,76,78,79,83)
gen sec_purpose3=inlist(x2810,1,3,4,10,24,61,63,65,67,69,71,72,73,74,75,76,78,79,83)
gen sec_purpose4=inlist(x2827,1,3,4,10,24,61,63,65,67,69,71,72,73,74,75,76,78,79,83)
gen sec_purpose5=inlist(x2910,1,3,4,10,24,61,63,65,67,69,71,72,73,74,75,76,78,79,83)
gen sec_purpose6=inlist(x2927,1,3,4,10,24,61,63,65,67,69,71,72,73,74,75,76,78,79,83)

*Have installment loan dummies: for each loan, HH has loan AND it's not for purposes that can be secured credit 
gen hinstall1=(x2710!=0 & sec_purpose1==0)
gen hinstall2=(x2727!=0 & sec_purpose2==0) 
gen hinstall3=(x2810!=0 & sec_purpose3==0)
gen hinstall4=(x2827!=0 & sec_purpose4==0) 
gen hinstall5=(x2910!=0 & sec_purpose5==0)
gen hinstall6=(x2927!=0 & sec_purpose6==0) 
gen hinstall=(hinstall1==1 | hinstall2==1 | hinstall3==1 | hinstall4==1 | hinstall5==1 | hinstall6==1) 
gen install=max(0,x2723)*(sec_purpose1==0)+max(0,x2740)*(sec_purpose2==0)+max(0,x2823)*(sec_purpose3==0)+max(0,x2840)*(sec_purpose4==0)+max(0,x2923)*(sec_purpose5==0)+max(0,x2940) *(sec_purpose6==0) 
  
  
*[4] PENSION PLAN BORROWING
 *Only in account-type
if (`year'<2004) { 
	*Respondent
	 gen debt_pension_B_r=max(x4229,0)*(x4230==5)+max(x4329,0)*(x4330==5)+max(x4429,0)*(x4430==5)
	*Spouse
	 gen debt_pension_B_s=max(x4829,0)*(x4830==5)+max(x4929,0)*(x4930==5)+max(x5029,0)*(x5030==5)
	 gen debt_pension=debt_pension_B_r+debt_pension_B_s
 }
 if (`year'==2004 | `year'==2007) {
	*Respondent
	gen debt_pension_B_r=max(0,x11027)*(x11070==5)+max(0,x11127)*(x11170==5)+max(0,x11227)*(x11270==5)
	*Spouse
	gen debt_pension_B_s=max(0,x11327)*(x11370==5)+max(0,x11427)*(x11470==5)+max(0,x11527)*(x11570==5)
	gen debt_pension=debt_pension_B_r+debt_pension_B_s
}
 if (`year'==2010) {
 	*Respondent
	gen debt_pension_B_r=max(0,x11027)*(x11070==5)+max(0,x11127)*(x11170==5)
	*Spouse
	gen debt_pension_B_s=max(0,x11327)*(x11370==5)+max(0,x11427)*(x11470==5)
	gen debt_pension=debt_pension_B_r+debt_pension_B_s
}

	
 *2.2 SUBTOTAL
 gen subt_fin_debt=debt_cc+debt_cl+debt_pension
 
 
 *-----------2.3 DEBT PAYMENT ----------
 *[1] CREDIT CARDS
 *Assume 2.5% pay of credit card balance
 gen debtpay_cc=0.025*debt_cc
 gen cc_limit=max(0,x414) 
 
 *[2] LINES OF CREDIT 
 *FIRST 3
 *Non farm share of the residence: 100% for individuals who do not live in farm/ranch
 *1- farm share for individuals who live in farm/ranch 
 local loc_mconv "x1110 x1121 x1132"
 local n: word count `loc_mconv'
 local i=1
 while `i'<=`n' {
 	  local var2conv: word `i' of `loc_mconv'
 	  MCONV `var2conv'
 	  gen MFRQ`var2conv'=FR
	  drop FR
 	  local i=`i'+1
 	}
	
 gen debtpay_loc1=((x1103==1)*non_farm_share+(x1103!=1))*(x1109!=-1)*x1109*MFRQx1110
 gen debtpay_loc2=((x1114==1)*non_farm_share+(x1114!=1))*(x1120!=-1)*x1120*MFRQx1121
 gen debtpay_loc3=((x1125==1)*non_farm_share+(x1125!=1))*(x1131!=-1)*x1131*MFRQx1132
 
 *OTHER LINES OF CREDIT (MORE THAN 3) 
 *No debt payment info given in SCF 
 *So, we assume payment on other LOCs/debt on other LOCs = payment on the last non-zero LOC of first 3/ debt on the last non-zero LOC of first 3
 gen debtpay_otloc=0
 replace debtpay_otloc=((x1125==1)*non_farm_share+(x1125!=1))*max(0,x1131)/x1130*MFRQx1132*(x1130!=0)*x1136 if x1136>0
 replace debtpay_otloc=debtpay_otloc+((x1114==1)*non_farm_share+(x1114!=1))*max(0,1120)/x1119*MFRQx1121*(x1119!=0 & x1130==0)*x1136 if x1136>0
 replace debtpay_otloc=debtpay_otloc+((x1103==1)*non_farm_share+(x1103!=1))*max(0,x1109)/x1108*MFRQx1110*(x1108!=0 & x1119==0 & x1130==0)*x1136 if x1136>0
 *If debt in first 3 LOCs=0 for this HH, payment on other LOCs/debt on other LOCs for this HH= population median payment rate for first 3 LOCs.
 *(Median payment rate for 1995 is 0.0316)
 replace debtpay_otloc=debtpay_otloc+0.0316*x1136*(x1108==0 & x1119==0 & x1130==0) if x1136>0 
 
 *[3] CONSUMER LOANS
 *Regular payments. Coding -1: no regular payments
 *If there is no regular payments, go to typical payments
 *Regular payment: Loan 1-6
 *NOTE: we're excluding debt payments for non residential real estates investment
 *(1) either this HH do not have non-residential real estates (2) or R report the loan not for non-residential real estates (coding 78)
 if (`year'==1989) {
	gen debtpay_cl_reg=(x2710!=78 | flag781==0)*max(0,x2718)
	replace debtpay_cl_reg=debtpay_cl_reg+(x2727!=78 | flag781==0)*max(0,x2735)
	replace debtpay_cl_reg=debtpay_cl_reg+(x2810!=78 | flag781==0)*max(0,x2818)
	replace debtpay_cl_reg=debtpay_cl_reg+(x2827!=78 | flag781==0)*max(0,x2835)
	replace debtpay_cl_reg=debtpay_cl_reg+(x2910!=78 | flag781==0)*max(0,x2918)
	replace debtpay_cl_reg=debtpay_cl_reg+(x2927!=78 | flag781==0)*max(0,x2935)
 }
 if (`year'>=1992) {
    local clr_mconv "x7527 x7526 x7525 x7524 x7523 x7522" 
	local clr_pay "x2718 x2735 x2818 x2835 x2918 x2935" 
	local clr_purpose "x2710 x2727 x2810 x2827 x2910 x2927"
	local i=1
	local n: word count `clr_mconv' 
	gen debtpay_cl_reg=0
	while `i'<=`n' {
		local var2conv: word `i' of `clr_mconv'
		local var_pay: word `i' of `clr_pay'
		local var_purpose: word `i' of `clr_purpose' 
		MCONV `var2conv'
		gen MFRQ`var2conv'=FR
		replace debtpay_cl_reg=debtpay_cl_reg+(`var_purpose'!=78 | flag781==0)*MFRQ`var2conv'*max(0,`var_pay')
		drop FR
		local i=`i'+1
	}
	if (`year'>=1995) {
	    MCONV x7185 
		replace debtpay_cl_reg=debtpay_cl_reg+max(0,x7184)*FR
        drop FR
	}
	
 }
 
 
 *Typical payment: Loan 1-6
 gen debtpay_cl_typ=0
 local clt_mconv "x2720 x2737 x2820 x2837 x2920 x2937"
 local clt_pay "x2719 x2736 x2819 x2836 x2919 x2936"
 local clt_purpose "x2710 x2727 x2810 x2827 x2910 x2927"
 local i=1 
 local n: word count `cl_mconv'
 while `i'<=`n' {
	local var2conv: word `i' of `clt_mconv'
	local var_pay: word `i' of `clt_pay'
	local var_purpose: word `i' of `clt_purpose' 
	MCONV `var2conv'
	gen MFRQ`var2conv'=FR
	replace debtpay_cl_typ=debtpay_cl_typ+(`var_purpose'!=78 | flag781==0)*MFRQ`var2conv'*max(0,`var_pay') 
	drop FR
	local i=`i'+1
}
  gen debtpay_cl=debtpay_cl_reg+debtpay_cl_typ
  
*[3]' Education LOANS
*First 6 for regular payments: x7816 x7839 x7862 x7916 x7939 x7962
* The following 6 for typical payments: x7818 x7841 x7864 x7918 x7941 x7964
* Last one for all other remaining loan payments 
if (`year'>=1992) {
	 local edul_mconv "x7816 x7839 x7862 x7916 x7939 x7962 x7818 x7841 x7864 x7918 x7941 x7964"
	 local edul_pay "x7815 x7838 x7861 x7915 x7938 x7961 x7817 x7840 x7863 x7917 x7940 x7963"
	 local i=1
	 local n: word count `edul_mconv'
	 while `i'<`n' {
	   local var2conv: word `i' of `edul_mconv'
	   local var_pay: word `i' of `edul_pay'
	   MCONV `var2conv'
	   replace debtpay_cl=debtpay_cl+FR*max(0,`var_pay') 
	   drop FR
	   local i=`i'+1
	   }
	if (`year'>=1995) {
	   MCONV x7181
	   replace debtpay_cl=debtpay_cl+FR*max(0,x7180)
	   drop FR
	}
}

*[4] PENSION PLAN (ACCOUNT TYPE)
*Assume an annual interest rate 6.5% 
if (`year'<=1995) {
	gen debtpay_pp=(1.065^(1/12)-1)*(max(0,x4229)*(x4230==5)+max(0,x4329)*(x4330==5)+max(0,x4429)*(x4430==5)+max(0,x4829)*(x4830==5)+max(0,x4929)*(x4930==5)+max(0,x5029)*(x5030==5))
 }
if (`year'==1998 | `year'==2001) {
	*Since 1998, detailed payment of borrowing against pension plan are reported
	local pp_mconv "x7212 x7221 x7230 x7279 x7288 x7297"
	local pp_pay "x7211 x7220 x7229 x7278 x7287 x7296"
	*Whether this loan is recorded before 
	local pp_ifrb "x4230 x4330 x4430 x4830 x4930 x5030" 
	local i=1
	local n: word count `pp_mconv'
	gen debtpay_pp=0 
	while `i'<`n' {
		local var2conv: word `i' of `pp_mconv'
		local var_pay: word `i' of `pp_pay'
		local var_ifrb: word `i' of `pp_ifrb'
		MCONV `var2conv' 
		replace debtpay_pp=debtpay_pp+FR*max(0,`var_pay')*(`var_ifrb'==5) 
		drop FR
		local i=`i'+1
	}
}
if (`year'==2004 | `year'==2007) {
	local pp_mconv "x11029 x11129 x11229 x11329 x11429 x11529"
	local pp_pay "x11028 x11128 x11228 x11328 x11428 x11528"
	*Whether this loan is recorded before
	local pp_ifrb "x11070 x11170 x11270 x11370 x11470 x11570" 
	local i=1 
	local n: word count `pp_mconv'
	gen debtpay_pp=0
	while `i'<`n' {
		local var2conv: word `i' of `pp_mconv'
		local var_pay: word `i' of `pp_pay'
		local var_ifrb: word `i' of `pp_ifrb'
		MCONV `var2conv'
		replace debtpay_pp=debtpay_pp+FR*max(0,`var_pay')*(`var_ifrb'==5) 
		drop FR
        local i=`i'+1
    }
}	
if (`year'==2010) {
	local pp_mconv "x11029 x11129 x11329 x11429"
	local pp_pay "x11028 x11128 x11328 x11428"
	*Whether this loan is recorded before
	local pp_ifrb "x11070 x11170 x11370 x11470" 
	local i=1 
	local n: word count `pp_mconv'
	gen debtpay_pp=0
	while `i'<`n' {
		local var2conv: word `i' of `pp_mconv'
		local var_pay: word `i' of `pp_pay'
		local var_ifrb: word `i' of `pp_ifrb'
		MCONV `var2conv'
		replace debtpay_pp=debtpay_pp+FR*max(0,`var_pay')*(`var_ifrb'==5) 
		drop FR
        local i=`i'+1
    }
}	

*2.3 SUBTOTAL
gen subt_fin_debtpay=debtpay_cc+debtpay_loc1+debtpay_loc2+debtpay_loc3+debtpay_otloc+debtpay_cl+debtpay_pp
 

 
 *************3 VEHICLES ASSETS/DEBTS/DEBT PAYMENTS******************
 *+++++++++++3.1 ASSET ++++++++++++++++++
 *(1) Cars
 if (`year'>=1995) {
	gen vehicle=x8166+x8167+x8168+x8188+x2422
 }
  if (`year'<1995) {
	gen vehicle=x8166+x8167+x8168+x2422
 }
 *(2) Autos, motohomes, RVs, airplanes and boats
 gen other_vehicle=x2506+x2606+x2623
 
 *3.1 SUBTOTAL
 gen subt_veh_asset=vehicle+other_vehicle
 
 *-----------3.2 DEBT ------------------
 if (`year'>=1995) {
	 gen debt_vehicle=x2218+x2318+x2418+x2424+x7169
 }
  if (`year'<1995) {
	 gen debt_vehicle=x2218+x2318+x2418+x2424
 }
 gen debt_other_vehicle=x2519+x2619+x2625
 
 *3.2 SUBTOTAL
 gen subt_veh_debt=debt_vehicle+debt_other_vehicle
 
 *-----------3.3 DEBT PAYMENT--------------
 MCONV x2426
 gen MFRQx2426=FR
 drop FR
 if (`year'<=1989) {
 gen debtpay_vehicle_reg=max(0,x2213)+max(0,x2313)+max(0,x2413)+max(0,x2425)*MFRQx2426
}
 if (`year'>=1992) {
   *Additional information of payment frequency available for loan 10, 11,12 and another extra loan
    MCONV x7537
	gen MFRQx7537=FR
    drop FR
	MCONV x7536 
	gen MFRQx7536=FR
    drop FR
    MCONV x7535 
	gen MFRQx7535=FR
    drop FR
    gen debtpay_vehicle_reg=MFRQx7537*max(0,x2213)+MFRQx7536*max(0,x2313)+MFRQx7535*max(0,x2413)+max(0,x2425)*MFRQx2426

	if (`year'>=1995) {
    MCONV x7163
	gen MFRQx7163=FR
    drop FR
	replace debtpay_vehicle_reg=debtpay_vehicle_reg+MFRQx7163*max(0,x7162)
	}
	}
	
 *Loan 14,15
 MCONV x2627
 gen MFRQx2627=FR
 drop FR
 if (`year'<=1989) {
 gen debtpay_other_vehicle_reg=max(0,x2514)+max(0,x2614)+max(0,x2626)*MFRQx2627
 }
 if (`year'>=1992) {
   MCONV x7531
   gen MFRQx7531=FR
   drop FR 
   MCONV x7530
   gen MFRQx7530=FR
   drop FR 
   gen debtpay_other_vehicle_reg=MFRQx7531*max(0,x2514)+MFRQx7530*max(0,x2614)+max(0,x2626)*MFRQx2627
}   

 *Typical Payment if there's no regular payment: Loan 10,11,12,14,15
 gen debtpay_vehicle_typ=0
 local veh_mconv "x2215 x2315 x2415 x2516 x2616"
 local veh_pay "x2214 x2314 x2414 x2515 x2615"
 local i=1
 local n: word count `veh_mconv'
 while `i'<=`n' {
 	local var2conv: word `i' of `veh_mconv'
 	local var_pay: word `i' of `veh_pay'
 	MCONV `var2conv'
 	replace debtpay_vehicle_typ=debtpay_vehicle_typ+FR*max(0,`var_pay')
 	drop FR
 	local i=`i'+1
}

*Typical payment for the extra vehicle loan since 1995 
if (`year'>=1995) {
	MCONV x7165
	replace debtpay_vehicle_typ=debtpay_vehicle_typ+FR*max(0,x7164)
	drop FR
}
 *3.3  SUBTOTAL
 gen subt_veh_debtpay=debtpay_vehicle_reg+debtpay_other_vehicle_reg+debtpay_vehicle_typ
 
 
 *-----------------------3.4 Other Payment---------------------
 *Auto Leases
 local autols_mconv "x2106 x2113 x2118"
 local autols_pay "x2105 x2112 x2117"
 gen autolspay=0
 local i=1
 local n: word count `autols_mconv'
 while `i'<=`n' {
	local var2conv: word `i' of `autols_mconv' 
	local var_pay: word `i' of `autols_pay'
	MCONV `var2conv' 
	replace autolspay=autolspay+FR*max(0,`var_pay')
	drop FR
	local i=`i'+1
	}

 gen subt_veh_otpay=autolspay
 
 *Subtotal with vehicle debt payments
 gen subt_veh_allpay=subt_veh_debtpay+subt_veh_otpay 
 
 
 ************4 BUSINESS ASSETS/DEBTS/DEBT PAYMENTS ******************
 *+++++++++++4.1 ASSET ++++++++++++++++++
 *Farm/ranch business (Net asset) 
 gen biz_fr=max(0,x507)/1d4*(max(0,x513)+max(0,x526)-max(0,x805)-max(0,x905)-max(0,x1005))
 replace biz_fr=biz_fr-(x1103==1)*max(0,x1108)*max(0,x507)/1d4-(x1114==1)*max(0,x1119)*max(0,x507)/1d4-(x1125==1)*max(0,x1130)*max(0,x507)/1d4

 *Amount that this business owe you - amount you owe this business
 if (`year'<=2007) {
	 gen biz_debt_hold=x3124+x3224+x3324-(x3126*(x3127==5)+x3226*(x3227==5)+x3326*(x3327==5))
	 *Equity 
	 *Active manage
	 gen biz_equ_hold_am=max(0,x3129)+max(0,x3229)+max(0,x3329)+max(0,x3335)
	 *Personal assets that serve as collateral (only if asset not recorded before)
	 gen biz_col=max(0,x3121)*inlist(x3122,1,6)+max(0,x3221)*inlist(x3222,1,6)+max(0,x3321)*inlist(x3322,1,6)
	 *Noactive manage
	 gen biz_equ_hold_nam=max(0,x3408)+max(0,x3412)+max(0,x3416)+max(0,x3420)+max(0,x3424)+max(0,x3428)
 }
 if (`year'==2010) {
	  gen biz_debt_hold=x3124+x3224-(x3126*(x3127==5)+x3226*(x3227==5))
	 *Equity 
	 *Active manage
	 gen biz_equ_hold_am=max(0,x3129)+max(0,x3229)+max(0,x3335)
	 *Personal assets that serve as collateral (only if asset not recorded before)
	 gen biz_col=max(0,x3121)*inlist(x3122,1,6)+max(0,x3221)*inlist(x3222,1,6)
	 *Noactive manage
	 gen biz_equ_hold_nam=max(0,x3408)+max(0,x3412)+max(0,x3416)+max(0,x3420)+max(0,x3428)
 
 }
 
 *4.1  SUBTOTAL
 gen subt_biz_asset=biz_fr+biz_debt_hold+biz_equ_hold_am+biz_equ_hold_nam+biz_col
 
 *--------------------4.2 DEBT -------------------------
 gen subt_biz_debt=0
 
 *--------------------4.3 DEBT PAYMENT--------------
 
 gen subt_biz_debtpay=0
 
 
 ************5 MISSCELLENOUS ASSETS/DEBTS/DEBT PAYMENTS***********
 *++++++++++5.1 ASSET +++++++++++
 *(1) Nonfinancial asset from other assets in section 1
 gen  nf_other=x4022*(!inlist(x4020,61,62,63,64,65,66,71,72,73,74,77,80,81,-7))+x4026*(!inlist(x4024,61,62,63,64,65,66,71,72,73,74,77,80,81,-7))+x4030*(!inlist(x4028,61,62,63,64,65,66,71,72,73,74,77,80,81,-7))

 gen subt_mis_asset=nf_other
 
 *-----------5.2 DEBT -----------------
 *(1) Margin loans
 if (`year'==1995) {
	gen debt_margl=max(0,x3932)*(x7194==5)
 }
 if (`year'!=1995) {
	gen debt_margl=max(0,x3932) 
 }
 *(2) Loans against insurance policies
 gen debt_ipl=max(0,x4010)*(x4009==5)
 
*(3) Other debts
 gen debt_rest=max(0,x4032)
 
 *5.2 SUBTOTAL
 gen subt_mis_debt=debt_margl+debt_ipl+debt_rest
 
 *-----------5.3 DEBT PAYMENT----------
 *(1)Margin loans
 *Assume an annual interest rate 8%
 gen debtpay_margl=(1.08^(1/12)-1)*debt_margl
 
 *(2) Loans against insurance policies
 MCONV x4012
 gen debtpay_ipl=FR*max(0,x4011)
 drop FR
 
 *5.3 SUBTOTAL
 gen subt_mis_debtpay=debtpay_margl+debtpay_ipl
 
 ************
 *NET WORTH*
 ***********
 gen t_asset=subt_fin_asset+subt_rs_asset+subt_veh_asset+subt_biz_asset+subt_mis_asset
 gen t_debt=subt_fin_debt+subt_rs_debt+subt_veh_debt+subt_biz_debt+subt_mis_debt
 gen t_debtpay=subt_fin_debtpay+subt_rs_debtpay+subt_veh_debtpay+subt_biz_debtpay+subt_mis_debtpay
 gen t_allpay=subt_fin_debtpay+subt_rs_allpay+subt_veh_allpay+subt_biz_debtpay+subt_mis_debtpay
 gen networth=t_asset-t_debt
 
 ******************************
 *CONSUMER DEBT / SECURED DEBT*
 ******************************
 gen cons_debt=debt_cc+debt_nheloc+debt_nheloc_other+debt_cl+debt_hp_hi+debt_vehicle+debt_other_vehicle
 gen sec_debt=debt_prin_rs+debt_lc+debt_other_rs+debt_heloc+debt_heloc_other+debt_vehicle+debt_other_vehicle+debt_pension+debt_ipl
 
 ********************
 *LIQUID ASSET LEVEL*
 ******************
 gen liquid=cheque_acc+mm_acc+bro_acc+saving_acc

 
 
 *Clean up
drop x* j* MFRQ*  
 
 local list1 id weight age educ edcl race marrd ownhome yradd yrjob selfemp occup hins denied_credit bcc_hold acc_hold delinq delinq60 cc_limit
 local list_fin2 debt_cc debt_bcc debt_heloc debt_heloc_other debt_nheloc debt_nheloc_other debt_cl debt_pension subt_fin_debt hloc hnheloc hnheloc1 nheloc install hinstall
 local list_fin3 debtpay_cc debtpay_loc1 debtpay_loc2 debtpay_loc3 debtpay_otloc debtpay_cl debtpay_pp subt_fin_debtpay 
 local list_rs1 house_fr house llc otrs_rs subt_rs_asset 
 local list_rs2 debt_prin_rs debt_lc debt_other_rs debt_hp_hi subt_rs_debt 
 local list_rs3 debtpay_prin_rs debtpay_lc debtpay_other_rs debtpay_hp_hi subt_rs_debtpay subt_rs_allpay
 local list_veh1 vehicle other_vehicle subt_veh_asset 
 local list_veh2 debt_vehicle debt_other_vehicle subt_veh_debt 
 local list_veh3 subt_veh_debtpay subt_veh_allpay
 local list_biz1 biz_fr biz_debt_hold biz_equ_hold_am biz_equ_hold_nam subt_biz_asset
 local list_biz2 subt_biz_debt
 local list_biz3 subt_biz_debtpay
 local list_mis1 nf_other subt_mis_asset
 local list_mis2 subt_mis_debt
 local list_mis3 subt_mis_debtpay 
 local list_total t_asset t_debt t_debtpay t_allpay networth cons_debt sec_debt liquid income 
 
 if (`year'<1992) {
	 local list_fin1 cheque_acc retire_acc mm_acc bro_acc cds saving_acc mf save_bond other_bond_fv stock atm_int pp lf_ins other_fin subt_fin_asset
 }
 if (`year'==1992) {
	  local list_fin1 cheque_acc retire_acc mm_acc bro_acc cds saving_acc mf save_bond other_bond_fv other_bond_mv stock atm_int pp lf_ins other_fin subt_fin_asset
 }
  if (`year'>=1995) {
	  local list_fin1 ccir cheque_acc retire_acc mm_acc bro_acc cds saving_acc mf save_bond other_bond_fv other_bond_mv stock atm_int pp lf_ins other_fin subt_fin_asset
 }
 
 
 local keeplist `list1' `list_fin1' `list_fin2' `list_fin3' `list_rs1' `list_rs2' `list_rs3' `list_veh1' `list_veh2' `list_veh3' `list_biz1' `list_biz2' `list_biz3' `list_mis1' `list_mis2' `list_mis3' `list_total'
 keep `keeplist' 
 save basics_`year'.dta,replace

 

