% Computing equilibria of the model in
% Livshits, MacGee and Tertilt "Democratization of Credit"
% 
% Underlying assumptions:
% Linear utility
% Uniform distribution of HH types
%   rho in [a,1] is HH type = prob of high income (yh),
%   (1 - rho) is probability of yl
% Risk-free contract always offered -- no fixed cost
%
% Lender sees noisy signal of HH type 
% HH know own type
%
% Program loops over grid of noisy signals
%
% Convention: Variables/matrices ending in "ps" denote perfect signal case
% Note: Some portions of the code are redundant. For example, it allows one
%       to compute the equilibrium of the model when risk-free loan
%       supplier also has to pay the fixed cost chi (and thus the risk-free
%       loan may not be offered in equilibrium). Some of these redundant
%       portions are commented out, while others are still present.

clear all; format long;

% Specify Parameters and Variables
% Preference paramaters
beta = 0.94;

% Income
yl =10;  % Endowment in low state in period 2
yh =30; % Endowment in high state in period 2
abar = 0.9; %Lowest probability of getting the high income draw.

% Bankruptcy paramaters
phii = [0.0]; %Fixed cost of filing for bankruptcy
gamma = 0.25; %Fraction of earnings burned

% Borrowing limits for loan contracts 
Lbarrf = phii + gamma*yl; %Face value Risk-free
Lbar = phii + gamma*yh; %Face value Risky

% Interest Rate/Bond Price
rsave = 0.04; % Risk free Saving
qbar = 1/(1 + rsave); %Risk free borrowing
% Note: Require qbar > beta !!!
qbarv = [qbar qbar qbar];

chi = 0.000025; %Fixed Cost: chi 

avgincome = ((1+abar)*yh + (1-abar)*yl)/2;
totalincome = ((1+abar)*yh + (1-abar)*yl)*(1-abar)/2;

n_grid =  900; % Number of alpha points for the comparative statics
    % alpha is precision of the signal = probability the signal is accurate
alphamin = 0.85;
alphamax = 0.99999;
alphastep = (alphamax-alphamin)/(n_grid-1);
alphagrid= [alphamin:alphastep:alphamax]; % Signal accuracy grid 

intlength = ( (2*chi*(1-abar))/(qbar*Lbar)  )^(0.5); % Smallest size of the interval
        % served by a single risky contract - that under the perfectly informative signal
max_int = (1-abar)/intlength;

ncon = round(max_int-.5);%Number of risky contracts to potentially check -- extra stuff reported as zeros
    % Note that we are not checking if the last contract extends beyond the
    % lower bound of support abar. This is easily verified by looking at
    % the output
n_ps =1;% Set size of ps to 1

% Setting up Storage

rfqvecps = qbar*ones(ncon,n_ps); %matrix to store potential risk free bond prices if alpha = 1
riskprem = qbar*ones(ncon,n_grid); %matrix to store risk premium in each bond price
% Comment: Vectors since code adopted from version where risk-free endogenous - rf always offered here
tildeqvec = zeros(ncon,n_grid); %matrix to store bond prices
tildeqvecps = zeros(ncon,n_ps); %matrix to store bond prices if alpha = 1
qvec = zeros(ncon,n_grid); %matrix to store bond prices after taking into account participation by good types with low signals.
rfqvec = zeros(ncon,n_grid); %matrix to store potential risk free bond prices
overprem = zeros(ncon,n_grid); %matrix to store overhead premium in each bond price
ivec = zeros(ncon,n_grid); %Vector to store cut-offs for contracts
ivecps = zeros(ncon,n_ps); %Vector to store cut-offs for contracts if alpha =1
particvec = zeros(ncon,n_grid); %Vector to store AUTARKY participation constraints -- NEGATIVE values means non-binding
particvecps = zeros(ncon,n_ps); %Vector to store AUTARKY participation constraints for perfect signal-- NEGATIVE values means non-binding
particvecrf = zeros(ncon,n_grid); %Vector to store RF verssu risky participation constraints -- NEGATIVE values means non-binding
particvecrfps = zeros(ncon,n_ps); %Vector to store RF versus risky participation constraints for perfect signal-- NEGATIVE values means non-binding
rhonalphaaut  = zeros(ncon,n_grid); %Vector to store cut-off at which HH with low signals and high types prefer autarky to risky contract.
rhonalpharf  = zeros(ncon,n_grid); %Vector to store cut-off at which HH with low signals and high types prefer R-F to risky contract. 
rhonalpha  = zeros(ncon,n_grid); %Vector to store cut-off at which HH with low signals and high types prefer R-F to risky contract. This is min of rhonalphaaut and rhonalpharf if RF viable
default_pc =  zeros(ncon,n_grid); %matrix to store default on each contract
Discharge_rate_adv =  zeros(1,n_grid); %matrix to store average discharge rate 
measure_borrow =  zeros(ncon,n_grid); %matrix to store measure of borrowers on each contract

pivec = zeros(ncon,n_grid); %Vector to store OPERATING profits -- should equal chi if algebra correct!
pivecps = zeros(ncon,n_ps); %Vector to store OPERATING profits -- should equal chi if algebra correct!
netpicheck =  zeros(ncon,n_grid); %Vector to store Net OPERATING profits -- should equal 0 if algebra correct!
netpicheckps =  zeros(ncon,n_ps); %Vector to store Net OPERATING profits -- should equal 0 if algebra correct!
aggmat = zeros(10,n_grid); %Matrix to store aggregates for fixed chi for each 
aggmatps = zeros(9,n_ps); %Matrix to store aggregates for each chi for perfect signal case
particrf = zeros(ncon,n_grid); %Vector to store participation constraints for RF -- NEGATIVE values means RF dominates
nrisky = zeros(1,n_grid); %Vector to store number of risky contracts for each value of alpha
nriskyps = zeros(1,n_ps); %Vector to store number of risky contracts for each value of alpha
fractionborrriskyps = zeros(1,n_ps); %Vector to store fraction of population with risky borrowing for each value of alpha
fractionborrrisky = zeros(1,n_grid); %Vector to store fraction of population with risky borrowing for each value of alpha
r_risky_1= zeros(1,n_grid); %Vector to store interest rate on lowest risk risky contracts for each value of alpha
r_risky_max= zeros(1,n_grid); %Vector to store interest rate on HIGHEST risk risky contracts for each value of alpha
r_rf= zeros(1,n_grid); %Vector to store interest rate on risk FREE contracts for each value of alpha
r_risky_avg = zeros(1,n_grid); %Vector to store AVERAGE interest rate on RISKY contracts for each value of alpha

C_1_agg = zeros(1,n_grid); %Vector to store aggregate Cons. in period 1 for each value of alpha
C_2_agg = zeros(1,n_grid); %Vector to store aggregate Cons. in period 2 for each value of alpha
Util_equal = zeros(1,n_grid); %Vector to store C_1_agg + beta C_2_agg for each value of alpha

checkmeas = zeros(1,n_grid); checkmeas2 = zeros(1,n_grid); 

partriskfree = zeros(ncon,1); 
ngrid= zeros(ncon,1); % Specify vector of possible risky contracts 


% Step 0: Construct perfect signal equilibrium -- intervals and bond prices 
ivecps(1,1) = 1; % Top of first contract interval for perfect signal case
for j = 1:ncon
  % Compute risk-free bond price for each cut-off 
  % Note -- RF prices are one cut-off off from risky    
  rfqvecps(j,1) = qbar; % Left-over from when risk-free endogenous 
  ivecps(j+1,1) = ivecps(j,1) - ((2*chi*(1-abar))/(qbar*Lbar))^(0.5);
  tildeqvecps(j,1) = qbar*(ivecps(j+1,1) );
  % Check participation for each potential contract
  % Autarky is redundant -- included as a check 
  % For each risky contract -- NEGATIVE means risky preferred to autarky 
  % -- for household with highest signal in pool
  particvecps(j,1) = beta*(gamma*(1-ivecps(j,1))*yl/Lbar + ivecps(j,1)) - tildeqvecps(j,1); %Autarky
  % Risk-free versus risky contract -- NEGATIVE means risky 
  % preferred to RISK-FREE -- for household with highest signal in bin
  particvecrfps(j,1) = (rfqvecps(j,1) - beta)*Lbarrf - tildeqvecps(j,1)*Lbar + beta*( gamma*(1-ivecps(j,1))*yl + ivecps(j,1)*Lbar) ; %alpha =1     
end; % end of for j = 1:ncon
     
% Loop to compute remaining intervals of the contract.
particps = particvecps(1,1); particrfcps = particvecrfps(1,1);
k =0; j =1;
while (particps <= 0) && (particrfcps <= 0)      
  nriskyps(1) = j;
  % Participation constraint: check it does not bind for highest type in bin
  particps = particvecps(j,1);
  if particps > 0
	ivecps(j+1,1) = 0 ;%Set last cut-off to zero.
    nriskyps(1) = j-1; % Risky contract j-1 satisifies part constraint, j does not.
  end;
  % Note: Normalize by 1/(1-a) since we assume standardized uniform distribution
  pivecps(j,1) = (1/(1-abar))*Lbar*( -( ivecps(j,1) - ivecps(j+1,1) )*tildeqvecps(j,1) + ( (ivecps(j,1))^2 - (ivecps(j+1,1))^2 )*qbar/2 );
  netpicheckps(j,1) = pivecps(j,1) - chi;  % Check that operating profit on this contract is equal to chi
    
  % Need to check risk-free contract
  % For each contract, check if risk free dominates contract.

  % Check if cut-off prefers risky contract to this risk free
  % Check for the top guy in bin -- so for contract k this is ivec k
       
  particrfcps = particvecrfps(j,1) ; % Variable to check in for loop over j cut-offs
  if particrfcps > 0
	ivecps(j+1,1) = 0 ;%Next cut-off must be zero 
    nriskyps(1) = j-1; % Risky contract k fails RFpart constraint.
  end;   
               
  j = j+1;
end; % end of while 
    
% Compute the rest of equilibrium values
% Compute defaults
% Be careful here: remember cut-off for riskiest HH served is # of contracts + 1
aggmatps(1,1) = chi; %Value of fixed contract cost
aggmatps(2,1) = nriskyps(1);% Store number of risky contracts
aggmatps(3,1) = ivecps(max(nriskyps(1),1),1);% Store top cut-off of riskiest contract offered in equilibrium
% Note: be careful -- when no contracts, top is still equal to 1 here
aggmatps(4,1) = ivecps(nriskyps(1)+1,1);% Store Bottom cut-off of riskiest contract offered in equilibrium
fractionborrriskyps(1,1) = (1 - aggmatps(4,1))/(1-abar); % Fraction of population with risky borrowing
% Construct matrix of lengths of each interval
ilengthps(1:nriskyps(1),:) = ivecps(1:nriskyps(1),:) - ivecps(2:nriskyps(1)+1,:) ;
aggmatps(5,1) = (1/(1-abar))*(1/2 - ivec(nriskyps(1)+1,1) + ((ivec(nriskyps(1)+1,1))^2)/2); % Total defaults
  
 
% COMPUTE NOISY SIGNAL (alpha <1) EQUILIBRIUM

% Step 1: Construct candidate equilibrium -- intervals and bond prices 
% IF incentive constraints do NOT bind
% Note: This may return some junk (negative cut-offs): we deal with
% below when we check participation and feasibility

%LOOP : This is starting possibility where no types drop out!
% Loop over values of alpha -- index is n
for n = 1:n_grid
  alpha = alphagrid(n);
  % For each chi, compute possible cut-offs and bond prices if no
  % participation constraints bind.
  % Compute the critical lower cut-off for risky contract for which best HH
  % with lower signal would drop out
  sigma_n_bind = 1/alpha*(beta/qbar - (1 - alpha)*(1+abar)/2); 

  ivec(1,n) = 1; % Top of first contract interval
  for j = 1:ncon  
    % Compute risk-free bond price for each cut-off (including no risky)
    % ASSUME RF always offered
    rfqvec(j,n) = qbar;     % - Lbarrf*chi/(( (ivec(j,n)-abar)/(1-abar) ));                          
    ivec(j+1,n) = ivec(j,n) - ( 2*chi*(1-abar)/(alpha*qbar*Lbar))^(0.5);
    if ivec(j+1,n) >= abar
      tildeqvec(j,n) = qbar*(alpha*ivec(j+1,n) + (1 - alpha)*(1+abar)/2);
    elseif ivec(j+1,n) <  abar
      tildeqvec(j,n) = -10; rfqvec(j+1,n) = 0; % Set risky bond price to negative for partic constraints below
    end; % End of if over negative cut-offs
        
    % Compute the participation values for each potential contract
    % Start with autarky for each risky contract -- NEGATIVE means risky
    % preferred to autarky -- for household with highest ACCURATE signal in bin
    particvec(j,n) = beta*(gamma*(1-ivec(j,n))*yl/Lbar + ivec(j,n)) - tildeqvec(j,n); %alpha < 1
        
    % Risk-free versus risky contract -- NEGATIVE means risky 
    % preferred to RISK-FREE -- for household with highest ACCURATE signal in bin
    particvecrf(j,n) = (rfqvec(j,n) - beta)*Lbarrf - (tildeqvec(j,n)*Lbar + beta*( gamma*(1-ivec(j,n))*yl - ivec(j,n)*Lbar) ) ; %alpha < 1
        
    % Compute cut-off for HH with low signals and High types
    rhonalphaaut(j,n)  = (tildeqvec(j,n)*Lbar - beta*gamma*yl )/( beta*(Lbar - gamma*yl ) );
    rhonalpharf(j,n)  =   (tildeqvec(j,n)*yh - qbar*yl )/( beta* (yh - yl) );
        
  end; % end of for j = 1:ncon
end;% End of for n = 1:n_grid


% STEP 2: Compute equilibrium if autarky constraint binds
% Use Step 1 candidate equilibrium as initial guess .
% The following loop checks participation issues due to
% imperfect information for risk-free case
qj1c1 = zeros(ncon,n_grid); qj1c2 = zeros(ncon,n_grid);
qj1c1rf = zeros(ncon,n_grid); qj1c2rf = zeros(ncon,n_grid);

for n = 1:n_grid

  alpha = alphagrid(n);     
        
  % Check Participation decisions
  % Initialize particpation relative to auatarky + risk-free
  partic = particvec(1,n); particrfc = particvecrf(1,n);
  j=1; k=0;

  qvec(:,n) =  tildeqvec(:,n); % Assign initial value to qvec -- this is what we use in the end
 
  while (partic <= 0) && (particrfc <= 0)
    k=j; % Two counters since ivec has one more element than # contracts
    nrisky(n) = k;
    
    % Check that high types with low alphas do not drop out    
    % if rhonalphaaut(j,n) >= 1
    if rhonalpharf(j,n)  >= 1
      j = j+1;
      partic = particvec(j,n); particrfc = particvecrf(j,n);
    % elseif rhonalphaaut(j,n) < 1
    elseif rhonalpharf(j,n) < 1
     
      %disp('WARNING! High types with low alpha want out!!!');
      %disp('Value of chi         Risky Contract number    Cutoff Value ');
      %disp([chi j rhonalphaaut(j,n)])
    
      % Compute the bond price if autarky participation binds
      aquad = (1 - alpha)*( Lbar/(beta*(Lbar - gamma*yl)) - (qbar/2)*( Lbar^2/(beta*(Lbar - gamma*yl) )^2 ) );
      bquad = alpha - abar + (1-alpha)*( qbar* (Lbar*beta*gamma*yl)/((beta*(Lbar - gamma*yl))^2) - (beta*gamma*yl)/(beta*(Lbar - gamma*yl)) );
      cquad = qbar*((1-alpha)/2)*( abar^2 - (beta*gamma*yl)^2/( (beta*(Lbar - gamma*yl))^2 )) - qbar*alpha*(1-abar)*ivec(j+1,n); 
      % Select the positive root since negative bond prices can't work
      qj1c1(j,n) =( -bquad + (bquad^2 - 4*aquad*cquad )^(0.5) )/(2*aquad);
      qj1c2(j,n) =( -bquad - (bquad^2 - 4*aquad*cquad )^(0.5) )/(2*aquad);
      %tildeqvec(j,n)
      qvec(j,n) = max( qj1c1(j,n), qj1c2(j,n));
      rhonalpharf(j,n)  = (qvec(j,n)*Lbar - beta*gamma*yl )/( beta*(Lbar - gamma*yl ) );
      % Compute participation for top type with true signal in bin using new
      % bond price
      particvec(j,n) = beta*(gamma*(1-ivec(j,n))*yl/Lbar + ivec(j,n)) - qvec(j,n); %alpha < 1
      particvecrf(j,n) = (rfqvec(j,n) - beta)*Lbarrf - qvec(j,n)*Lbar + beta*( gamma*(1-ivec(j,n))*yl + ivec(j,n)*Lbar) ; %alpha < 1
    
      partic = particvec(j,n);  particrfc = particvecrf(j,n);
    
      % Check participation -- terminate loop if particapation violated
      if ivec(j+2,n) <=  abar
        particvec(j,n) = 1; partic = particvec(j,n); % Set partic to 1 if leave region
        % Note: "j+2" here since we need to stop BEFORE we add in contract j
        % which is not feasible.
      end; % End of if over negative cut-offs
        
      if partic > 0
		ivec(j+1,n) = 0 ;%Set last cut-off to zero.
        nrisky(n) = j-1; % Risky contract j-1 satisifies part constraint, j does not.
      end;
        	
      % Check if cut-off prefers risky contract to this risk free
      % Check for the top guy in bin -- so for contract k this is ivec k
       
      if particrfc > 0
		ivec(j+1,n) = 0 ;%Next cut-off must also be zero -- even if not rejected by participation check above.
        nrisky(n) = j-1; % Risky contract k fails RFpart constraint.
      end;
        
      j = j +1; %update counter
    
    end; % if ivec(j+1,n) >= sigma_n_bind

  end; % end of while

%  n = n+1; % End of for n = 1:n_grid
end %End of for n = 1:n_grid


% Step 3: Compute Remainder of Equilibrium variables
% Note: STructure left from when RF endogenous and used AUTARKY CONSTRAINTS Equilibrium 
% AS GUESS TO CONSTRUCT NEW CANDIATE
% USING THIS COMPUTE PARTICPATION USING NEW RF
% BOND PRICES and ITERATE on this.
rfguessvec = zeros(1,n_grid); %vector to store initial risk-free for guess from autarky constraints.
rhonalpharf = zeros(ncon,n_grid); %Matrix to store new cut-offs for high types who drop out.
qriskynew = zeros(nrisky(n_grid),n_grid); %Matrix to store updated risky bond prices -- matrix assumes that the lowest chi will generate the largest number of risky contracts
% Note: Loop over alpha largest number of contracts is for LARGEST ALPHA!!!
particvecnew = zeros(ncon,n_grid); %Vector to store AUTARKY participation constraints for updated in loop -- NEGATIVE values means non-binding
particvecrfnew = zeros(ncon,n_grid); %Vector to store RF verssu risky participation constraints for updated in loop -- NEGATIVE values means non-binding
percentqn = zeros(ncon,n_grid); %Vector to store
qriskynew_alloptout = zeros(nrisky(n_grid),n_grid); %Matrix to store updated risky bond prices 
  
    
for n = 1:n_grid   %Loop over possible ALPHA values

  alpha = alphagrid(n);
  aggmat(1,n) = chi; % Store chi value in first row of aggregate reporting
  rfguessvec(1,n) = qbar;       %- Lbarrf*chi/ rfdemand(1,n);
  
  % Compute rho_n^alpha and new qn 
  % Verify participation still holds
        
  for j=1:nrisky(n)
                
    % rhonalpharf(j,n): cut-off for participation of high types with low signals 
    % who prefer risk-free contract to risky contract offered public signal
    rhonalpharf(j,n) = min(1, (qvec(j,n)*yh - qbar*yl )/( beta*(yh - yl ) )); % Cut-off cannot be above 1
        
    if  rhonalpharf(j,n) < 1
      % Compute the bond price when opts-out choose RF
      aquadrf = (1 - alpha)*( yh/(beta*(yh - yl)) - (qbar/2)*( yh^2/(beta*(yh - yl) )^2 ) );
      bquadrf = alpha - abar + (1-alpha)*( qbar* (yh*qbar*yl)/((beta*(yh - yl))^2) - (qbar*yl)/(beta*(yh - yl)) );
      cquadrf = qbar*((1-alpha)/2)*( abar^2 - (qbar*yl)^2/( (beta*(yh - yl))^2 )) - qbar*alpha*(1-abar)*ivec(j+1,n); 
      % Select the positive root since negative bond prices can't work
      qj1c1rf(j,n) =( -bquadrf + (bquadrf^2 - 4*aquadrf*cquadrf )^(0.5) )/(2*aquadrf);
      qj1c2rf(j,n) =( -bquadrf - (bquadrf^2 - 4*aquadrf*cquadrf )^(0.5) )/(2*aquadrf);
      qvec(j,n) = max( qj1c1rf(j,n), qj1c2rf(j,n));
      rhonalpharf(j,n)  = (qvec(j,n)*yh - qbar*yl )/( beta*(yh - yl ) );
    end   
       
    % CHECK THAT WE HAVE CONSISTENT rhonalpha and qtilde
    riskyrhs = qbar*ivec(j+1,n)*alpha + qbar*(1-alpha)*( rhonalpharf(j,n)^2 - abar^2)/(2*(1-abar));
    qriskynew(j,n) = riskyrhs /(alpha + (1 - alpha)*( rhonalpharf(j,n) - abar)/(1-abar) );
    tildeqvec(j,n) = qriskynew(j,n);
    percentqn(j,n) = (qvec(j,n)- qriskynew(j,n))/qvec(j,n) ;
    
    % Check participation constraint on risky contracts.
     
    particvecnew(j,n) = beta*(gamma*(1-ivec(j,n))*yl/Lbar + ivec(j,n)) - qriskynew(j,n); %alpha < 1
    particvecrfnew(j,n) = (rfguessvec(1,n) - beta)*Lbarrf - qriskynew(j,n)*Lbar + beta*( gamma*(1-ivec(j,n))*yl + ivec(j,n)*Lbar) ; %alpha < 1
    rhonalpha(j,n) = min(rhonalpharf(j,n), rhonalphaaut(j,n));
    
    if particvecrfnew(j,n) > 0
      j = nrisky(n);
	  nrisky(n) = j-1; % Risky contract k fails RFpart constraint.
    end;
  
  end; %for loop over risky contracts (j)
    
  % Compute total "demand" for risk-free bond
  % rfdemand: Ineligible for risky + adverse selection dropouts
  % Dropouts: (1-alpha) mislabeled * measure dropouts*length risky contract
  % Be CAREFUL -- RF prices are one cut-off off from risky
  % Cut-off is number risky contracts + 1
  
  mindropout = min(ones(nrisky(n),1),rhonalpharf(1:nrisky(n),n)); %Min of 1 and top type with low signal to drop out
  highlowsignals = ones(nrisky(n),1) - max(mindropout,abar*ones(nrisky(n),1));
  rfdemand(1,n) = (ivec(nrisky(n) +1,n) - abar)/(1-abar) + ((1-alpha)/(1-abar))*(ones(1,nrisky(n))*highlowsignals)*(ivec(1,n)- ivec(2,n) )/(1-abar);
 
 
  for j=1:nrisky(n)
    % Note: Normalize by 1/(1-a) since we work with standardized uniform distribution
    term1pivec = alpha*( (ivec(j,n))^2 - (ivec(j+1,n))^2 )/2 + (1-alpha)*(ivec(j,n) - ivec(j+1,n))*(  (rhonalpha(j,n))^2 - abar^2)/((1-abar)*2);
    pivec(j,n) = (1/(1-abar))*Lbar*(qbar*term1pivec - tildeqvec(j,n)*(ivec(j,n) - ivec(j+1,n))*(alpha + (1-alpha)*(rhonalpha(j,n) - abar)/(1-abar) ) );
    netpicheck(j,n) = pivec(j,n) - chi;  % Check that operating profit on this contract is equal to chi
   
    % Compute defaults on each risky contract
    ilength1 = ivec(1,n) - ivec(2,n);
    noisy_def = ilength1*((1-alpha)/(1-abar))* ( rhonalpha(j,n) - abar  - (rhonalpha(j,n)^2 - abar^2)/2 )/(1-abar) ;
    default_pc(j,n) = noisy_def + (alpha/(1-abar))*(ivec(j,n) - ivec(j+1,n) - ( ivec(j,n)^2 - ivec(j+1,n)^2  )/2); 
    ilength1 = ivec(1,n) - ivec(2,n);
    measure_borrow(j,n)= alpha*ilength1/(1-abar) + ((1-alpha)/(1-abar))*( ilength1*(rhonalpha(j,n) - abar)/(1-abar) ) ; % Fraction of population with risky borrowing
   
  end; % of for j=1:nrisky(n)
 
  % Compute the rest of equilibrium values
  % Be careful here: remember cut-off for riskiest HH served is contracts + 1
  aggmat(2,n) = nrisky(n);% Store number of risky contracts
  aggmat(3,n) = ivec(max(nrisky(n),1),n); % Store top cut-off of riskiest contract offered in equilibrium
  % Note: be careful -- when no contracts, top is still equal to 1 here
  aggmat(4,n) = ivec(nrisky(n)+1,n);% Store Bottom cut-off of riskiest contract offered in equilibrium

  % Construct matrix of lengths of each interval
  ilength(1:nrisky(n),n) = ivec(1:nrisky(n),n) - ivec(2:nrisky(n)+1,n) ;
  fractionborrrisky(1,n) = alpha*(1 - aggmat(4,n))/(1-abar) + ((1-alpha)/(1-abar))*( ilength(1,n)*ones(1,nrisky(n))*(rhonalpha(1:nrisky(n),n) - ones(nrisky(n),1)*abar)/(1-abar) ) ; % Fraction of population with risky borrowing

  aggmat(5,n) = (alpha/(1-abar))*(1/2 - ivec(nrisky(n)+1,n) + ((ivec(nrisky(n)+1,n))^2)/2) + ((1-alpha)/(1-abar))* ilength(1,n)*ones(1,nrisky(n))*( rhonalpha(1:nrisky(n),n) - ones(nrisky(n),1)*abar  - (rhonalpha(1:nrisky(n),n).^2 - (ones(nrisky(n),1)*abar).^2)/2 )/(1-abar) ; % Total defaults

  aggmat(6,n) = Lbar*(measure_borrow(1:nrisky(n),n)')*tildeqvec(1:nrisky(n),n); % Total risky borrowing -- assuming marginal risky contract dominates riskfree!!!
  total_borrow_risky(n) = aggmat(6,n)/avgincome;  % Total risky borrowing as a share of total income

  Discharge_rate_adv(1,n) = (Lbar*(default_pc(1:nrisky(n),n)')*(tildeqvec(1:nrisky(n),n)) )/aggmat(6,n);

  aggmat(7,n) = fractionborrrisky(1,n)*Lbar; %Face value of risky borrowing

  aggmat(8,n) = nrisky(n)*chi/aggmat(6,n)*100; %Total overheadcosts as percentage of risky borrowing

  % Measure of risk-free borrowers
  aggmat(9,n) =  rfdemand(1,n);

  r_risky_1(n) = 1/tildeqvec(1,n) -1; %Interest rate on lowest-risk risky contract
  r_risky_max(n) = 1/tildeqvec(nrisky(n),n) -1; %Interest rate on highest-risk risky contract
  r_rf(n) = 1/rfguessvec(1,n)-1; %Interest rate on risk free contract
  % Compute average risky interest rate
  r_vec = ones(nrisky(n),1)./tildeqvec(1:nrisky(n),n) - ones(nrisky(n),1);
  measure_risky_vec = ilength(1,n)*ones(nrisky(n),1)/(1-abar) - ((1-alpha)/(1-abar))*( ilength(1,n)*(ones(nrisky(n),1) - rhonalpha(1:nrisky(n),n) )/(1-abar) ) ; % Fraction of population with risky borrowing
  measure_risky_vec2 = alpha*ilength(1,n)*ones(nrisky(n),1)/(1-abar) + ((1-alpha)/(1-abar))*( ilength(1,n)*(rhonalpha(1:nrisky(n),n) - ones(nrisky(n),1)*abar)/(1-abar) ) ; % Fraction of population with risky borrowing

  checkmeas(n) =ones(1,nrisky(n))* measure_risky_vec - fractionborrrisky(1,n);
  checkmeas2(n) =ones(1,nrisky(n))* measure_risky_vec2 - fractionborrrisky(1,n);

  r_risky_av = ones(1,nrisky(n))*(r_vec.*measure_risky_vec);
  r_risky_avg(n) = r_risky_av/fractionborrrisky(1,n);

  q_risky_av = (tildeqvec(1:nrisky(n),n)'*measure_risky_vec)/fractionborrrisky(1,n);

  % Compute risk premium and average overhead cost per loan type.
  %riskprem(k,n) = 0.5*(ivec(j,n)^2 - ivec(k,n)^2)/(ivec(j,n) - ivec(k,n));
  %overprem(k,n) = chi/( (ivec(j,n) - ivec(k,n))*tildeqvec(k,n)*Lbar ) ;
        
  % Compute Social Welfare with equal weights
  % c1 + beta c2
  % c1 = q * L
  C_1_agg(n) = (tildeqvec(1:nrisky(n),n)'*measure_risky_vec)*Lbar + aggmat(9,n)*Lbarrf*rfguessvec(1,n); %Period 1 Agg Consumption
  % Use aggmat(9,n) since it is zero if no rf contract offered!

  % Total endowment period 2
  Agg_end2 = (1 + abar)/2* yh + (1 - abar)/2* yl;
  % Total burnt in default
  burnt = gamma*yl*aggmat(5,n);
  % Total Repaid
  Repaid = (fractionborrrisky(1,n) - aggmat(5,n))*Lbar + aggmat(9,n)*Lbarrf;

  C_2_agg(n) = Agg_end2 - burnt - Repaid;
  Util_equal(n) = C_1_agg(n) + beta*C_2_agg(n);

end %End of for n = 1:n_grid

% Compute Default Rate: defaults/fraction borrowing
default_rate = aggmat(5,:)./fractionborrrisky(1,:);

% CHECK POSSIBLE DEVIATION CONTRACT
% Check if Contract for Unserved is Feasible
% Compute Possible deviation contracts
% Create grid of face values for deviating contract
k = 1;
firstrhon = zeros(1,n_grid); %Store first risky contract with rhonalpha <1

qdcheck = zeros(nrisky(k),n_grid);
Ldcheck = zeros(nrisky(k),n_grid);
pi_i_qdld = zeros(nrisky(k),n_grid);
pi_upper_qdld = zeros(nrisky(k),n_grid); % Store total operating pi from all conrtact intervals for each proposed deviation
% Matices for when we adjust qtilden in lowest opt out bin to account for exits 
qdcheck_adjq = zeros(nrisky(k),n_grid);
Ldcheck_adjq = zeros(nrisky(k),n_grid);
pi_i_qdld_adjq = zeros(nrisky(k),n_grid);
pi_upper_qdld_adjq = zeros(nrisky(k),n_grid); % Store total operating pi from all conrtact intervals for each proposed deviation

max_pi_dev = zeros(1,n_grid); 
max_pi_dev_adjq = zeros(1,n_grid); %Store profit from best deviating contract

for k =1:n_grid
  alpha = alphagrid(k); % Pins down value of alpha
  % For top of each risky contract interval, compute what deviating
  % contract would look like

  % Set counter for first risky contract with rhonalpha(j,k) < 1
  for j =2:nrisky(k)  
    if rhonalpha(j-1,k)>=1 && rhonalpha(j,k) < 1 ;
      firstrhon(k) = j;
    end;
  end

  % We compute a conservative upper bound on the profitability of the
  % potential deviation contract: 
  %     We compute the profits as if the prices of the existing contracts
  %     qvec(j,k) did not change in response.
  %     More precise calculation would require us to recompute the prices
  %     of the "existing" contracts, making them less attractive and
  %     pushing more customers into the deviation contract. But since all
  %     of these additional customers come from the extensive margin, they
  %     lower the average quality of the deviating borrowers, thus lowering
  %     profitability of the deviation. 
  % Thus, our much simpler calculation offers us a conservative upper bound

  % Compute Ld
  % Compute qd
  % j -- different risky contracts, k index over alpha
  for j=2:nrisky(k);
    % First we compute contract as if tildeqvec(j,k) was unchanged
    % This is for comparison purposes
    bottemp = (rfqvec(1,k) - beta)*Lbarrf - (tildeqvec(j,k) - beta *ivec(j,k))*Lbar;
    qdcheck(j,k) =  beta*( ivec(j,k)*(rfqvec(1,k) - beta)*Lbarrf - (tildeqvec(j,k) - beta *ivec(j,k))*Lbar)/bottemp;
    Ldcheck(j,k) = (rfqvec(1,k) - beta)*Lbarrf/(qdcheck(j,k) - beta);

    % The following portion of the code is built to account for fact that 
    %   more opt-outs lowers the bond price qn of the existing contracts
    %   To offer an upper bound, it assumes -- all households above cut-off opt-out.
    bottemp_adjq = (rfqvec(1,k) - beta)*Lbarrf - (qriskynew_alloptout(j,k) - beta *ivec(j,k))*Lbar;
    qdcheck_adjq(j,k) =  beta*( ivec(j,k)*(rfqvec(1,k) - beta)*Lbarrf - (qriskynew_alloptout(j,k) - beta *ivec(j,k))*Lbar)/bottemp;
    Ldcheck_adjq(j,k) = (rfqvec(1,k) - beta)*Lbarrf/(qdcheck_adjq(j,k) - beta);

    if Ldcheck_adjq(j,k) >= Lbar
      Ldcheck_adjq(j,k) = 0;
    end
    if Ldcheck(j,k)>= Lbar
      Ldcheck(j,k) = 0;
    end

    con_pi_i = (1 - alpha)*(ivec(1,k) - ivec(2,k))/(1 - abar)^2*.5; %Constant term

    if rhonalpha(j,k) == 1
      pi_i_qdld(j,k) = 0;
      pi_i_qdld_adjq(j,k) = 0;
    else
      pi_i_qdld(j,k) = con_pi_i*Ldcheck(j,k)*(1-ivec(j,k))*(rfqvec(1,k)*(1+ivec(j,k)) - 2*qdcheck(j,k));
      pi_i_qdld_adjq(j,k) = con_pi_i*Ldcheck_adjq(j,k)*(1-ivec(j,k))*(rfqvec(1,k)*(1+ivec(j,k)) - 2*qdcheck_adjq(j,k));
      %Compute upper bound on total profits -- loop over all risky contracts
      %above cut-off with rhonalpha < 1
      %pi_upper_qdld(j,k) = pi_i_qdld(j,k);
      pi_temp = pi_i_qdld(j,k);
      pi_temp_adjq = pi_i_qdld_adjq(j,k);

      for z = 1:(j-firstrhon(k))
        pi_i_qdldtemp = con_pi_i*Ldcheck(j,k)*(1-ivec(j-z,k))*(rfqvec(1,k)*(1+ivec(j-z,k)) - 2*qdcheck(j,k));
        pi_temp = pi_temp +  pi_i_qdldtemp;
        pi_i_qdldtemp_adjq = con_pi_i*Ldcheck_adjq(j,k)*(1-ivec(j-z,k))*(rfqvec(1,k)*(1+ivec(j-z,k)) - 2*qdcheck_adjq(j,k));
        pi_temp_adjq = pi_temp_adjq +  pi_i_qdldtemp_adjq;
      end
      pi_upper_qdld(j,k) =  pi_temp;
      pi_upper_qdld_adjq(j,k) =  pi_temp_adjq;
    
    end %end of if over rhonalpha(j,k) 
  end  % for for loop over risky contracts

  % Look at maximum deviation!
  max_pi_dev(k) = max(pi_upper_qdld(:,k)) - chi;
  max_pi_dev_adjq(k) = max(pi_upper_qdld_adjq(:,k)) - chi;

end  % End of loop over alphas

figure(1)
set(0,'DefaultAxesColorOrder',[0 0 0],...
      'DefaultAxesLineStyleOrder','-|--|:', ...
      'DefaultLineLinewidth',1.5);
% subplot(4,2,1)
% plot(alphagrid(:),nrisky(:));
% title('A: Number of Risky Contracts')
% xlabel('\alpha','FontSize',10)
% axis tight
% subplot(4,2,2)
% plot(alphagrid(:),ilength(1,:));
% title('B: Length Risky Contract Interval' )
% %xlabel('alpha','FontSize',6)
% axis tight
subplot(4,2,1)
%chigrid(:),fractionborrriskyps(1,:)
plot(alphagrid(:),fractionborrrisky(1,:),alphagrid(:),(1-aggmat(4,:))/(1-abar));
title('A: Fraction Population with Risky Debt','FontSize',12)
%legend('Borr.','Elig.','Location','East')
xlabel('Signal Accuracy (\alpha)','FontSize',10)
axis tight
subplot(4,2,2)
plot(alphagrid(:),total_borrow_risky(:));
title('B: Total Risky Debt','FontSize',12)
%legend('Avg qr','Max qr','Min qr')
%xlabel('alpha','FontSize',6)
axis tight
subplot(4,2,3)
plot(alphagrid(:),default_rate(1,:),'blue',alphagrid(:),aggmat(5,:)./(aggmat(9,:)+fractionborrrisky(1,:)));
%plot(alphagrid(:),default_rate(1,:),alphagrid(:),aggmat(5,:)./(aggmat(9,:)+fractionborrrisky(1,:)),alphagrid(:),Discharge_rate_adv(:));
title('C: Default Rates','FontSize',12)
%legend('Default/Borrower','Default/Pop','Orientation','Horizontal','Location',[0.2007 0.4098 0.2148 0.03762])
%xlabel('alpha','FontSize',6)
axis tight
axis 'auto y'
subplot(4,2,4)
plot(alphagrid(:),r_risky_1(1,:),'red',alphagrid(:),r_risky_avg(:),alphagrid(:),r_risky_max(1,:),'blue');
title('D: Interest Rates','FontSize',12)
%legend('Min','Avg','Max','Orientation','Horizontal','Location',[0.6777 0.4025 0.1799 0.03762])
%xlabel('alpha','FontSize',6)
axis tight
subplot(4,2,5)
%chigrid(:),fractionborrriskyps(1,:)
plot(alphagrid(:),aggmat(8,:));
title('E: Overhead Costs as Percent Borrowing','FontSize',12)
%legend('Avg qr','Max qr','Min qr')
%xlabel('alpha','FontSize',6)
axis tight
subplot(4,2,6)
plot(alphagrid(:),Util_equal(:));
title('F: Ex-Ante Expected Weflare','FontSize',12)
%xlabel('alpha','FontSize',6)
axis tight
set(gcf, 'PaperPositionMode', 'manual');
set(gcf, 'PaperUnits', 'inches');
set(gcf, 'PaperPosition', [0.25 0.25 8.00 10.50]);
saveas(gcf,'alpha.fig');
print -deps alpha;


% Figure on cut-offs for deviation contract

figure(5)
%subplot(2,1,1)
plot(alphagrid(:),max_pi_dev(:),alphagrid(:),max_pi_dev_adjq(:));
title('Profit of Best Deviant')
xlabel('pi','FontSize',6)
axis tight
