
clear all
set memory 800m
set more off

*************************************************************************************
*************************************************************************************
**This file:                                                                       **
**  (1) counts Percent of HHs who own a bank/any credit card                       **
**  (2) percentage of HHs that has a negative balance on a bank/any credit card    **
** by income quintile In POPULATION & in REGRESSION SAMPLE                         **
*************************************************************************************
*************************************************************************************

cd "D:\Dropbox\RA Work\RA Jim\Data"

local year=1989

use basics_`year'.dta,clear

*****************
*DROP REPLICATES*
*****************

*Droping duplicates that ID in the form of --i, i=2,3,4,5
if (`year'!=1983) {
	gen rep_id=real(substr(string(id),-1,.))
	keep if rep_id==1
}

gen rnd_weight=round(weight) 


**********************
*SAMPLE 1: POPULATION*
**********************
xtile inccode=income [fw=rnd_weight],n(5) 

*Number of Obersvations
display("NUMBER OF OBSERVATIONS")
dis _N

***********
*Ownership*
***********
display("PERC HHS THAT HAVE CARDS IN POPULATION") 
table inccode [iw=weight], content(n income mean bcc_hold mean acc_hold) format(%9.2f) 
mean bcc_hold acc_hold [iw=weight] 

******************
*Negative balance*
******************

gen nb_acc=(debt_cc>0) 
gen nb_bcc=(debt_bcc>0) 


display("PERC HHS WITH NEGATIVE BALANCE IN POPULATION") 
table inccode [iw=weight], content(n income mean nb_bcc mean nb_acc) format(%9.2f)
mean nb_bcc nb_acc [iw=weight]

	
gen cpi1983=80
gen cpi1989=100
gen cpi1992=113
gen cpi1995=123
gen cpi1998=131
gen cpi2001=143
gen cpi2004=152
gen cpi2007=167
gen cpi2010=176

*Transform values in all other years into constant 1989 dollars
if (`year'!=1989) {
	replace income=income*cpi1989/cpi`year'
	replace networth=networth*cpi1989/cpi`year'
	replace t_debt=t_debt*cpi1989/cpi`year'
	replace debt_cc=debt_cc*cpi1989/cpi`year'
	replace debt_bcc=debt_bcc*cpi1989/cpi`year'
}


*****************
*Balance > $100 *
*****************

gen acc100=(debt_cc>=100) 
gen bcc100=(debt_bcc>=100)


display ("PERC HHS WITH BALANCE >= $100 IN POPULATION") 
table inccode [iw=weight], content(n income mean bcc100 mean acc100) format(%9.2f) 
mean bcc100 acc100 [iw=weight] 

*****************
*Balance > $500 *
*****************

gen acc500=(debt_cc>=500) 
gen bcc500=(debt_bcc>=500)

display ("PERC HHS WITH BALANCE >= $500 IN POPULATION") 
table inccode [iw=weight], content(n income mean bcc500 mean acc500) format(%9.2f) 
mean bcc500 acc500 [iw=weight]

drop inccode

*****************************
*SAMPLE 2: Regression Sample*
*****************************

keep if age<=65 & networth<5e6 & subt_fin_asset<5e6

*Number of Obersvations
display("NUMBER OF OBSERVATIONS")
dis _N

xtile inccode=income [fw=rnd_weight],n(5) 

***********
*Ownership*
***********
display("PERC HHS THAT HAVE CARDS IN REGRESSION SAMPLE") 
table inccode [iw=weight], content(n income mean bcc_hold mean acc_hold) format(%9.2f) 
mean bcc_hold acc_hold [iw=weight]


******************
*Negative balance*
****************** 
display("PERC HHS WITH NEGATIVE BALANCE IN REGRESSION SAMPLE") 
table inccode [iw=weight], content(n income mean nb_bcc mean nb_acc) format(%9.2f)
mean nb_bcc nb_acc [iw=weight]

*****************
*Balance > $100 *
*****************

display ("PERC HHS WITH BALANCE >= $100 IN REGRESSION SAMPLE") 
table inccode [iw=weight], content(n income mean bcc100 mean acc100) format(%9.2f) 
mean bcc100 acc100 [iw=weight] 



*****************
*Balance > $500 *
*****************

display ("PERC HHS WITH BALANCE >= $500 IN REGRESSION SAMPLE") 
table inccode [iw=weight], content(n income mean bcc500 mean acc500) format(%9.2f) 
mean bcc500 acc500 [iw=weight]




