clear all 

set more off

************************************************************************************
*This file plots CDF of credit card borrowing vs income percentiles in 1983 vs 2004*
************************************************************************************

cd "D:\Skydrive\RA Work\RA Jim\Data"

use basics_1983.dta,clear


gen rnd_weight=round(weight) 

*Standardize income on a 0-100 scale 
pctile inc_pctl=income [fw=rnd_weight],nq(100) genp(percent) 

gen inccode=1 if income<inc_pctl[1]

forvalues i=2(1)99 {
    replace inccode=`i' if income>=inc_pctl[`i'-1] & income<inc_pctl[`i']
}

replace inccode=100 if income>=inc_pctl[99] 

by inccode, sort: egen tdebtcc_byinc=total(weight*debt_cc)  
egen tdebtcc=total(weight*debt_cc)
gen pdf=tdebtcc_byinc/tdebtcc

collapse (mean) tdebtcc_byinc tdebtcc pdf, by(inccode) 

gen cdf=sum(pdf) 
sort inccode 

rename tdebtcc_byinc tdebtcc_byinc1983
rename tdebtcc tdebtcc1983
rename pdf pdf1983
rename cdf cdf1983 

save 4cc_debt_cdf1983.dta,replace 


use basics_2004.dta,clear 

*****************
*DROP REPLICATES*
*****************

*Droping duplicates that ID in the form of --i, i=2,3,4,5
gen rep_id=real(substr(string(id),-1,.))
keep if rep_id==1

gen rnd_weight=round(weight) 

*Standardize income on a 0-100 scale 
pctile inc_pctl=income [fw=rnd_weight],nq(100) genp(percent)

gen inccode=1 if income<inc_pctl[1]

forvalues i=2(1)99 {
    replace inccode=`i' if income>=inc_pctl[`i'-1] & income<inc_pctl[`i']
}

replace inccode=100 if income>=inc_pctl[99] 

by inccode, sort: egen tdebtcc_byinc=total(weight*debt_cc)  
egen tdebtcc=total(weight*debt_cc)
gen pdf=tdebtcc_byinc/tdebtcc

collapse (mean) tdebtcc_byinc tdebtcc pdf, by(inccode) 

gen cdf=sum(pdf) 

sort inccode 
rename tdebtcc_byinc tdebtcc_byinc2004
rename tdebtcc tdebtcc2004
rename pdf pdf2004
rename cdf cdf2004 

save 4cc_debt_cdf2004.dta,replace 

*Plot CDF of credit card bollowing vs income percentiles in 1983 vs 2004 
use 4cc_debt_cdf1983.dta,clear
sort inccode
merge inccode using 4cc_debt_cdf2004.dta
twoway (line cdf1983 inccode) || (line cdf2004 inccode)







