clear all
set more off
set memory 800m
set maxvar 10000

********************************************************************
********************************************************************
**This file counts                                                **
**  (1) % of HHs who have unsecured lines of credit               **
**  (2) % of HHs that has a negative balance on it                **
**by income quintile in POPULATION & in REGRESSION SAMPLE         **
**Last update: July 14 2015                                       **
********************************************************************
********************************************************************

cd "D:\Dropbox\RA Work\RA Jim\Data"

local year=1995

use basics_`year'.dta,clear

*****************
*DROP REPLICATES*
*****************

*Droping duplicates that ID in the form of --i, i=2,3,4,5
if (`year'!=1983) {
	gen rep_id=real(substr(string(id),-1,.))
	keep if rep_id==1
}

gen rnd_weight=round(weight) 

mean hloc [iw=weight]

**********************
*SAMPLE 1: POPULATION*
**********************

xtile inccode=income [fw=rnd_weight],n(5) 


*Number of Obersvations
display("NUMBER OF OBSERVATIONS")
dis _N

************************************
*Negative Balance, > $100, >$500   *
************************************
*negative balance
gen nb_nheloc=(nheloc>0)
*negative balance>100  
gen nheloc100=(nheloc>100)
*negative balance>500 
gen nheloc500=(nheloc>500) 

*CPI list: constant 1989 dollars
gen cpi1983=80
gen cpi1989=100
gen cpi1992=113
gen cpi1995=123
gen cpi1998=131
gen cpi2001=143
gen cpi2004=152
gen cpi2007=167
gen cpi2010=176

*Transform values in all other years into constant 1989 dollars
if (`year'!=1989) {
	replace income=income*cpi1989/cpi`year'
	replace networth=networth*cpi1989/cpi`year'
	replace t_debt=t_debt*cpi1989/cpi`year'
	replace debt_cc=debt_cc*cpi1989/cpi`year'
	replace debt_bcc=debt_bcc*cpi1989/cpi`year'
	replace nheloc=nheloc*cpi1989/cpi`year'
}

*All 
mean hnheloc nb_nheloc nheloc100 nheloc500 [iw=weight]
*By income groups 
display ("% HHS WITH ACCESS TO UNSECURED DEBT, NEGATIVE BALANCE, NEGATIVE BALANCE (>$100) AND NEGATIVE BALANCE (>$500)") 
table inccode [iw=weight], content(mean hnheloc mean nb_nheloc mean nheloc100 mean nheloc500) format(%9.3f) 

drop inccode

*****************************
*SAMPLE 2: Regression Sample*
*****************************
keep if age<=65 & networth<5e6 & subt_fin_asset<5e6

*Number of Obersvations
display("NUMBER OF OBSERVATIONS")
dis _N

xtile inccode=income [fw=rnd_weight],n(5) 

*All
mean hnheloc nb_nheloc nheloc100 nheloc500 [iw=weight]
*By income groups 
display ("% HHS WITH ACCESS TO UNSECURED DEBT, NEGATIVE BALANCE, NEGATIVE BALANCE (>$100) AND NEGATIVE BALANCE (>$500)") 
table inccode [iw=weight], content(mean hnheloc mean nb_nheloc mean nheloc100 mean nheloc500) format(%9.3f) 



